/* 

$Id $
 
Copyright (c) 2001-2002 sync4j project
All rights reserved.
 
Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:
 
1. Redistributions of source code must retain the above copyright
notice, this list of conditions, and the following disclaimer.
 
2. Redistributions in binary form must reproduce the above copyright
notice, this list of conditions, and the disclaimer that follows
these conditions in the documentation and/or other materials
provided with the distribution.
 
3. The name "sync4j" must not be used to endorse or promote products
derived from this software without prior written permission.
 
4. Products derived from this software may not be called "sync4j", nor
may "sync4j" appear in their name, without prior written permission.
 
In addition, we request (but do not require) that you include in the
end-user documentation provided with the redistribution and/or in the
software itself an acknowledgement equivalent to the following:
 
"This product includes software developed by the
sync4j project."
 
THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
SUCH DAMAGE.
 
 */
package sync4j.client.j2me;

import java.io.*;
import javax.microedition.io.*;
import javax.microedition.midlet.*;
import javax.microedition.lcdui.*;

import sync4j.transport.j2me.http.client.SyncMLClient;

/**
 * This class is the client UI for SyncML data synchronization operation.
 * Its design should have been more flexible to accomodate clients of
 * other transport protocol.  
 * 
 * @author	<a href="mailto:sso@users.sourceforge.net">Simon So</a>
 * @since	SyncML 1.1
 */
public class ClientTester extends MIDlet implements CommandListener {
    private Form outputForm, waitForm;
    private Display display;
    private List menu;
    
    private Command okCmd = new Command("OK", Command.OK, 0);
    private Command exitCmd = new Command("Exit", Command.EXIT, 0);
    private Command cancelCmd = new Command("Cancel", Command.CANCEL, 0);
    
    private SyncMLClient syncMLClient;
    
    private static final String[] choices = {
        "1 Two way sync",   // MUST
        "2 Slow sync",          // MUST
    };
    
    protected void startApp() throws MIDletStateChangeException {
        display = Display.getDisplay(this);
        
        if (outputForm == null) {
            outputForm = new Form("Messages");
            menu = new List("Select:", List.IMPLICIT, choices, null);
            
            outputForm.addCommand(okCmd);
            menu.addCommand(okCmd);
            outputForm.addCommand(exitCmd);
            menu.addCommand(exitCmd);
            outputForm.setCommandListener(this);
            menu.setCommandListener(this);
            
            waitForm = new Form("Waiting...");
            waitForm.addCommand(cancelCmd);
            waitForm.setCommandListener(this);
        }
        
        display.setCurrent(menu);
        syncMLClient = new SyncMLClient(getAppProperty("SyncMLServer.URL"), 
                outputForm);
        new Thread(syncMLClient).start();
    }
    
    protected void pauseApp() {
    }
    
    protected void destroyApp(boolean unconditional)
            throws MIDletStateChangeException {
        System.out.println("Destroy App.");
        if (syncMLClient != null) {
            syncMLClient.stop();
        }
    }
    
    public void commandAction(Command cmd, Displayable activeDisplay) {
        if (cmd == exitCmd) {
            handleExit();
        } else if ((activeDisplay == menu) && (cmd == okCmd)) {
            handleOK(((List)activeDisplay).getSelectedIndex());
            return;
        } else if (cmd == cancelCmd) {
            display.setCurrent(outputForm);
            if (syncMLClient != null) {
                syncMLClient.cancel();
            }
        }
        
        display.setCurrent(menu);
    }
    
    private void handleExit(){
        try {
            System.out.println("exit.");
            destroyApp(true);
            notifyDestroyed();
                        
            if (syncMLClient != null) {
                syncMLClient.stop();
            }
        } catch (MIDletStateChangeException x){
            x.printStackTrace();
        }
    }
    
    /**
     * Triggers the syncML client into action.
     *
     * @param idx   the index to the synchronization type.
     */
    private void handleOK(int idx){        
        display.setCurrent(outputForm);
        syncMLClient.executeCommand(200 + idx);
    }
            
    /**
     * Alerts the user.  UI component not related to the network.
     */
    public void networkResponse(String s) {
        Alert a = new Alert("Response", s, null, null);
        a.setTimeout(Alert.FOREVER);
        display.setCurrent(a, outputForm);
    }
    
    /**
     * Alerts the user.  UI component not related to the network.
     */
    public void networkException(IOException ioe) {
        Alert a = new Alert("Exception", ioe.toString(), null, null);
        a.setTimeout(Alert.FOREVER);
        display.setCurrent(a, outputForm);
    }
}
