/*
 Copyright (c) 2001-2002 sync4j project
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.

 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.

 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */


package sync4j.framework.core;


/**
 *
 *  base class for "command" classes
 *
 *  @author Sean C. Sullivan
 *  @author Stefano Fornari @ Funambol
 *
 *  @version $Id: AbstractCommand.java,v 1.2 2003/02/25 10:59:06 stefano_fornari Exp $
 */
public abstract class AbstractCommand
{
    private CommandIdentifier m_cmdid;
    private boolean m_bNoResponse;

    /**
     *
     *  @param cmdid command identifier. Must be non-null.
     *
     *  @throws java.lang.NullPointerException
     *
     */
    AbstractCommand(final CommandIdentifier cmdid, final boolean bNoResponse)
    {
        if (cmdid == null)
        {
            throw new NullPointerException("cmdid == null");
        }
        
        m_cmdid       = cmdid      ; 
        m_bNoResponse = bNoResponse;
    }
    
    AbstractCommand(final CommandIdentifier cmdid)
    {
        this(cmdid, false);
    }

    /**
     *
     *  @return command identifier. The return value is guaranteed to be non-null.
     *
     */
    public final CommandIdentifier getCommandIdentifier()
    {
        return m_cmdid;
    }

    /**
     * @return true if the command doesn't require a response, false otherwise
     */
    public boolean getNoResponse()
    {
        return m_bNoResponse;
    }
    
    /**
     * @return the name of the command
     */
    public abstract String getName();
    
    /**
     *
     *  @return an XML representation of this object
     *
     */
    abstract String toXML();
    
    /**
     * For debug purposes
     */
    public String toString() {
        return toXML();
    }
}
