/*
 Copyright (c) 2001 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.  
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */


package sync4j.framework.core;


/**
 *  @author Sean C. Sullivan
 *  @author Stefano Fornari
 *
 *  @version $Id: AlertCode.java,v 1.4 2003/12/15 16:55:09 luigiafassina Exp $
 *  
 *  @see AlertCommand
 *
 *
 */
public final class AlertCode
{
  public final static int DISPLAY                       = 100;
  public final static int TWO_WAY                       = 200;
  public final static int SLOW                          = 201;
  public final static int ONE_WAY_FROM_CLIENT           = 202;
  public final static int REFRESH_FROM_CLIENT           = 203;
  public final static int ONE_WAY_FROM_SERVER           = 204;
  public final static int REFRESH_FROM_SERVER           = 205;
  public final static int TWO_WAY_BY_SERVER             = 206;
  public final static int ONE_WAY_FROM_CLIENT_BY_SERVER = 207;
  public final static int REFRESH_FROM_CLIENT_BY_SERVER = 208;
  public final static int ONE_WAY_FROM_SERVER_BY_SERVER = 209;
  public final static int REFRESH_FROM_SERVER_BY_SERVER = 210;
  public final static int RESULT_ALERT                  = 221;
  public final static int NEXT_MESSAGE                  = 222;

  private AlertCode() {}
  
  /**
   * Determines if the given code is an initialization code, such as one of:
   * <ul>
   *   <li> TWO_WAY                      
   *   <li> SLOW                         
   *   <li> ONE_WAY_FROM_CLIENT          
   *   <li> REFRESH_FROM_CLIENT          
   *   <li> ONE_WAY_FROM_SERVER          
   *   <li> REFRESH_FROM_SERVER        
   *   <li> TWO_WAY_BY_SERVER          
   *   <li> ONE_WAY_FROM_CLIENT_BY_SERVE
   *   <li> REFRESH_FROM_CLIENT_BY_SERVER
   *   <li> ONE_WAY_FROM_SERVER_BY_SERVER
   *   <li> REFRESH_FROM_SERVER_BY_SERVER
   * </ul>
   *
   * @param code the code to be checked
   *
   * @return true if the code is an initialization code, false otherwise
   */
  static public boolean isInitializationCode(int code) {
      return (  (code == TWO_WAY                      )
             || (code == SLOW                         )
             || (code == ONE_WAY_FROM_CLIENT          )
             || (code == REFRESH_FROM_CLIENT          )
             || (code == ONE_WAY_FROM_SERVER          )
             || (code == REFRESH_FROM_SERVER          )
             || (code == TWO_WAY_BY_SERVER            )
             || (code == ONE_WAY_FROM_CLIENT_BY_SERVER)
             || (code == REFRESH_FROM_CLIENT_BY_SERVER)
             || (code == ONE_WAY_FROM_SERVER_BY_SERVER)
             || (code == REFRESH_FROM_SERVER_BY_SERVER)
             );
  }
  
  /**
   * Determines if the given code represents a client only action, such as is 
   * one of:
   * <ul>
   *   <li>ONE_WAY_FROM_CLIENT</li>
   *   <li>REFRESH_FROM_CLIENT</li>
   * </ul>
   *
   * @param code the code to be checked
   *
   * @return true if the code represents a client only action, false otherwise
   */
  static public boolean isClientOnlyCode(int code) {
      return (  (code == ONE_WAY_FROM_CLIENT)
             || (code == REFRESH_FROM_CLIENT)
             );
  }

}
