/*
 Copyright (c) 2001-2002 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.
 
 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:
 
     "This product includes software developed by the
      sync4j project."
 
 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.
 
 */


package sync4j.framework.core;

import sync4j.framework.core.xml.*;


/**
 *
 *  corresponds to &ltAlert&gt element in SyncML represent DTD
 *
 *  @author Sean C. Sullivan
 *  @author Stefano Fornari @ Funambol
 *  @see    AlertCode
 *
 *  @version $Id: AlertCommand.java,v 1.7 2003/12/15 16:55:09 luigiafassina Exp $
 *
 *
 */
public final class AlertCommand extends ItemizedCommand {
    public static String COMMAND_NAME = "Alert";
    
    private boolean noResponse;
    private Credential cred;
    private int alertCode;
    
    /**
     *
     *  @param cmdid command identifier. Must be non-null.
     *  @param noResponse true if no response is required.
     *  @param cred authentication credentials. May be null.
     *  @param alertCode should be a value from {@link AlertCode}
     *  @param items must be non-null. Array length must be greater than zero.
     *               Array elements must be non-null.
     *
     *  @throws java.lang.NullPointerException
     *  @throws java.lang.IllegalArgumentException
     *
     *
     */
    public AlertCommand(
    final CommandIdentifier cmdid,
    final boolean noResponse,
    final Credential cred /* optional param */,
    final int alertCode,
    final Item items[] /* one or more items */) {
        super(cmdid, items);
        
        this.noResponse = noResponse;
        this.cred       = cred     ;
        this.alertCode  = alertCode;
    }
    
    /**
     *
     *  @param eAlert must be non-null.
     *
     */
    AlertCommand(final Element eAlert)
    throws RepresentationException {
        // todo : verify that eAlert is an <Alert>
        this(Util.extractCommandId(eAlert, true),
        Util.extractNoResp(eAlert, false),
        Util.extractCred(eAlert, false),
        Util.extractAlertCode(eAlert, false),
        Util.extractItems(eAlert, true));
    }
    
    /**
     *
     *  @return true if no response is required
     *
     */
    public boolean getNoResponse() {
        return noResponse;
    }
    
    /**
     *
     *  @return authentication credentials or null
     *
     */
    public Credential getCredential() {
        return cred;
    }
    
    /**
     *
     *  @return alert code
     *
     */
    public int getAlertCode() {
        return alertCode;
    }
    
    public void setAlertCode(int alertCode) {
        this.alertCode = alertCode;
    }
    
    /**
     *
     *   @return an array of Item objects
     *
     */
    public Item[] getItems() {
        return (Item[]) items.clone();
    }
    
    String toXML() {
        StringBuffer sbXML;
        sbXML = new StringBuffer();
        sbXML.append("<Alert>");
        sbXML.append(this.getCommandIdentifier().toXML());
        if (this.noResponse == true) {
            sbXML.append("<NoResp/>\n");
        }
        if (cred != null) {
            sbXML.append(cred.toXML());
        }
        if (alertCode > 0) {
            sbXML.append("<Data>");
            sbXML.append(alertCode);
            sbXML.append("</Data>\n");
        }
        for (int i = 0; i < items.length; i++) {
            sbXML.append(items[i].toXML());
        }
        sbXML.append("</Alert>\n");
        return sbXML.toString();
    }
    
    /**
     * @see AbstractCommand
     */
    public String getName() {
        return AlertCommand.COMMAND_NAME;
    }
    
}
