/*
 Copyright (c) 2001-2002 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.
 
 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:
 
     "This product includes software developed by the
      sync4j project."
 
 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.
 
 */


package sync4j.framework.core;

import sync4j.framework.tools.Base64;

/**
 *
 *  implements the "basic" authentication scheme
 *
 *  @version $Id: BasicAuthentication.java,v 1.7 2003/12/15 16:55:09 luigiafassina Exp $
 *  @author Sean C. Sullivan
 *  @author Stefano Fornari @ Funambol
 *
 *  @see    MD5Authentication
 *  @see    Credential
 *
 */
public final class BasicAuthentication extends Authentication {
    private final static String FORMAT_BASE64 = "b64";
    
    private String username = null;
    private String password = null;
    
    /**
     *
     *  @param username username. Must be non-null.
     *  @param password password. Must be non-null.
     *
     */
    public BasicAuthentication(
    final String username,
    final String password) {
        this(username + ":" + password, true);
    }
    
    /**
     * Create a new BasicCredential from an encoded or clear data.
     *
     * @param data the authentication data - NOT NULL
     * @param encode does data require encoding?
     *
     */
    public BasicAuthentication(String data, final boolean encode) {
        String clearData = null;
        
        if (encode) {
            this.data = new String(Base64.encode(data.getBytes()));
            clearData = data;
        } else {
            this.data = data;
            clearData = new String(Base64.decode(data.getBytes()));
        }
            
        int p = clearData.indexOf(':');
            
        if (p == -1) {
            username = clearData;
            password = null     ;
        } else {
            username = (p>0) ? clearData.substring(0, p) : "";
            password = (p<clearData.length()) ? clearData.substring(p) : "";
        }
    }
    
    public String getType() {
        return Constants.AUTH_TYPE_BASIC;
    }
    
    public String getFormat() {
        return BasicAuthentication.FORMAT_BASE64;
    }
    
    public String getUsername() {
        return username;
    }
    
    public String getPassword() {
        return password;
    }
}
