/*
 Copyright (c) 2001-2002 sync4j project
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.

 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.

 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */


package sync4j.framework.core;

/**
 *
 * this class corresponds to the &ltCmdID&gt element in SyncML represent DTD
 *
 *  @author Sean C. Sullivan
 *  @author Stefano Fornari @ Funambol
 *
 *  @version $Id: CommandIdentifier.java,v 1.4 2003/02/25 10:59:06 stefano_fornari Exp $
 */
//  todo : think about eliminating this class. Possibly replace usage
//         with a simple String - ?
public final class CommandIdentifier
implements java.io.Serializable
{
    private String m_strValue;

    /**
     *
     *  @param strValue must be non-null and String length
     *         must be greater than zero.
     *
     *  @throws java.lang.NullPointerException
     *  @throws java.lang.IllegalArgumentException
     *
     */
    public CommandIdentifier(final String strValue)
    {
        if (strValue == null)
        {
            throw new NullPointerException(
                    "strValue parameter is null");
        }
        else if (strValue.length() == 0)
        {
            throw new IllegalArgumentException(
                    "strValue parameter has length 0");
        }
        m_strValue = strValue;
    }

    /**
     *
     *  @param value must be greater than zero
     *
     *
     *  @throws java.lang.IllegalArgumentException
     *
     */
    public CommandIdentifier(final long value) {
        this(String.valueOf(value));
    }

    /**
     *
     *  @return value. The return value is guaranteed to be non-null.
     *
     */
    public String getValue()
    {
        return m_strValue;
    }

    public String toString()
    {
        return m_strValue;
    }

    public boolean equals(Object o) {
        String value = null;

        if (o instanceof String) {
            value = (String)o;
        } else if (o instanceof CommandIdentifier) {
            value = ((CommandIdentifier)o).getValue();
        }

        return (value == null) ? false : m_strValue.equals(value);
    }

    /**
     *
     *  @return an XML representation of this object
     *
     */
    String toXML()
    {
        StringBuffer sbXML;
        sbXML = new StringBuffer();
        sbXML.append("<CmdID>");
        sbXML.append(this.getValue());
        sbXML.append("</CmdID>\n");
        return sbXML.toString();
    }

}
