/*
 Copyright (c) 2001-2003 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.
 
 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:
 
     "This product includes software developed by the
      sync4j project."
 
 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.
 
 */


package sync4j.framework.core;

import sync4j.framework.core.RepresentationException;
import sync4j.framework.core.xml.Element;

/**
 *
 *  corresponds to the &ltCTCap&gt tag in the SyncML devinf DTD
 *
 *  @author Sean C. Sullivan
 *  @author Stefano Fornari @ Funambol
 *
 *  @version $Id: ContentTypeCapability.java,v 1.5 2003/07/19 16:28:27 stefano_fornari Exp $
 */

// todo : need to think about this class some more

public final class ContentTypeCapability {
    private ContentTypeCapabilityItem[] m_items;
    
    /**
     *
     *  @param items must be non-null. Also, the array elements must be non-null.
     *
     */
    public ContentTypeCapability(
    final ContentTypeCapabilityItem[] items) {
        if (items == null) {
            throw new NullPointerException("items parameter is null");
        }
        
        m_items = (ContentTypeCapabilityItem[]) items.clone();
        
        // todo : check array length - ?
        
        // check for null array elements
        for (int i = 0; i < m_items.length; i++) {
            if (m_items[i] == null) {
                throw new NullPointerException(
                "ContentTypeCapabilityItem[] array "
                + "contains a null value at index " + i);
            }
        }
        
    }
    
    /**
     *
     *  @param eCTCap element &ltCTCap&gt. Must be non-null.
     *
     */
    ContentTypeCapability(final Element eCTCap)
    throws RepresentationException {
        // todo : verify that eCTCap is <CTCap> - ?
        this(Util.extractContentTypeCapabilityItems(eCTCap, true));
    }
    
    /**
     *
     *  @return an array of ContentTypeCapabilityItem objects. The return value is guaranteed to
     *            be non-null. The array's elements are guaranteed to be non-null.
     *
     */
    public ContentTypeCapabilityItem[] getItems() {
        return (ContentTypeCapabilityItem[]) m_items.clone();
    }
    
    /**
     *
     *  @return an XML representation of this object
     *
     */
    String toXML() {
        StringBuffer sbXML;
        sbXML = new StringBuffer();
        sbXML.append("<CTCap>");
        for (int i = 0; i < m_items.length; i++) {
            sbXML.append(m_items[i].toXML());
        }
        sbXML.append("</CTCap>\n");
        return sbXML.toString();
    }
    
}
