/*
 Copyright (c) 2001-2002 sync4j project
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.

 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.

 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */


package sync4j.framework.core;


/**
 *
 *  loosely corresponds to the &ltCTCap&gt tag in the SyncML devinf DTD
 *  todo : need to think about this class some more
 *
 *  @see ContentTypeCapability
 *  @author Sean C. Sullivan
 *  @author Stefano Fornari @ Funambol
 *
 *  @version $Id: ContentTypeCapabilityItem.java,v 1.2 2003/02/25 10:59:06 stefano_fornari Exp $
 *
 */
public final class ContentTypeCapabilityItem
{
    private String m_strContentType;
    private ContentTypeProperty[] m_ctprops;

    // todo : need to think about this class some more

    /**
     *
     * @param strContentType content type. Must be non-null. Also,
     *           the string's length must be greater than zero.
     * @param ctprops Must be non-null. ( TODO : Array length must be greater than zero??? )
     *              The array's elements must be non-null.
     *
     */
    public ContentTypeCapabilityItem(
            final String strContentType /* corresponds to <CTType> element */,
            final ContentTypeProperty[] ctprops
            )
    {
        if (null == strContentType)
        {
            throw new NullPointerException("strContentType parameter is null");
        }
        else if (strContentType.length() < 1)
        {
            throw new IllegalArgumentException(
                        "strContentType parameter string length "
                        + "is less than one. Length = "
                        + strContentType.length());
        }

        if (null == ctprops)
        {
            throw new NullPointerException("ContentTypeProperty[] parameter is null");
        }

        m_strContentType = strContentType;

        m_ctprops = (ContentTypeProperty[]) ctprops.clone();

        // todo : check array length - ? Is a zero-length array acceptable?

        for (int i = 0; i < m_ctprops.length; i++)
        {
            if (m_ctprops[i] == null)
            {
                throw new NullPointerException(
                        "ContentTypeProperty[] array contains "
                        + "a null value at index " + i);
            }
        }

    }

    /**
     *
     * @return the return value is guaranteed to be non-null.
     *      The array's elements are guaranteed to be non-null.
     *
     */
    public ContentTypeProperty[] getContentTypeProperties()
    {
        return (ContentTypeProperty[]) m_ctprops.clone();
    }

    /**
     *
     * @return The return value is guaranteed to be non-null.
     *
     */
    public String getContentType()
    {
        return m_strContentType;
    }

    /**
     *
     * @return an XML representation of this object
     *
     */
    String toXML()
    {
        StringBuffer sbXML = new StringBuffer();
        sbXML.append("<CTType>");
        sbXML.append(this.getContentType());
        sbXML.append("</CTType>\n");
        for (int i = 0; i < m_ctprops.length; i++)
        {
            sbXML.append(m_ctprops[i].toXML());
        }
        return sbXML.toString();
    }
}
