/*
 Copyright (c) 2001-2002 sync4j project
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.

 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.

 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */


package sync4j.framework.core;

import sync4j.framework.core.RepresentationException;
import sync4j.framework.core.xml.Element;

/**
 *
 *  content type information
 *
 *  @author Sean C. Sullivan
 *  @author Stefano Fornari @ Funambol
 *
 *  @version $Id: ContentTypeInfo.java,v 1.3 2003/02/25 10:59:07 stefano_fornari Exp $
 */
public final class ContentTypeInfo
{
    private String m_strContentType;
    private String m_strVersion;

    /**
     *
     *
     *  @param strContentType corresponds to &ltCTType&gt element in the SyncML specification.
     *          Must be non-null.
     *          String length must be greater than zero.
     *  @param strVersion   corresponds to &ltVerCT&gt element in the SyncML specification.
     *          Must be non-null.
     *          String length must be greater than zero.
     *
     *  @throws java.lang.NullPointerException
     *  @throws java.lang.IllegalArgumentException
     *
     */
    public ContentTypeInfo(
            final String strContentType,
            final String strVersion)
    {
        m_strContentType = strContentType;
        m_strVersion = strVersion;
        if (strContentType == null)
        {
            throw new NullPointerException(
                    "strContentType parameter is null");
        }
        else if (strContentType.length() == 0)
        {
            throw new IllegalArgumentException(
                    "strContentType parameter: length is 0");
        }
        if (strVersion == null)
        {
            throw new NullPointerException(
                    "strVersion parameter is null");
        }
        else if (strVersion.length() == 0)
        {
            throw new IllegalArgumentException(
                    "strVersion parameter: length is 0");
        }
    }

    /**
     *
     *  @param e XML element. Must be non-null.
     *
     */
    ContentTypeInfo(final Element e)
            throws RepresentationException
    {
        // todo : verify that e is the correct element - ?
        this(Util.extractCTType(e, true),
                Util.extractVerCT(e, true));
    }

    /**
     *
     *  @return content type. The return value is guaranteed to be non-null.
     *
     */
    public String getContentType()
    {
        return m_strContentType;
    }

    /**
     *
     *  @return content version number. The return value is guaranteed to be non-null.
     *
     */
    public String getVersion()
    {
        return m_strVersion;
    }

    /**
     *
     *  @return an XML representation of this object
     *
     */
    String toXML()
    {
        StringBuffer sbXML = new StringBuffer();
        sbXML.append("<CTType>");
        sbXML.append(this.getContentType());
        sbXML.append("</CTType>\n");
        sbXML.append("<VerCT>");
        sbXML.append(this.getVersion());
        sbXML.append("</VerCT>\n");
        return sbXML.toString();
    }

}
