/*
 Copyright (c) 2001-2002 sync4j project
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.

 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.

 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */


package sync4j.framework.core;

/**
 *
 *
 *
 *
 *
 *  corresponds to the &ltVerDTD&gt tag in the SyncML devinf DTD
 *
 *  todo : possibly eliminate this class and replace all usage with String
 *
 *
 *  @author Sean C. Sullivan
 *  @author Stefano Fornari @ Funambol
 *
 *  @version $Id: DTDVersion.java,v 1.3 2003/12/15 16:55:09 luigiafassina Exp $
 */
public final class DTDVersion
{
    private final String m_strValue;

    /**
     *
     *  @param strValue must be non-null. Also, string length must be greater than zero
     *
     */
    public DTDVersion(final String strValue)
    {
        if (strValue == null)
        {
            throw new NullPointerException(
                    "strValue parameter is null");
        }
        else if (strValue.length() == 0)
        {
            throw new IllegalArgumentException(
                    "strValue parameter : length is zero");
        }
        m_strValue = strValue;
    }

    /**
     *
     *  @return The return value is guaranteed to be non-null.
     *
     */
    public String getValue()
    {
        return m_strValue;
    }

    public String toString()
    {
        return m_strValue;
    }

    public boolean equals(Object obj)
    {
        if ((obj instanceof DTDVersion) == false)
        {
            return false;
        }
        return (((DTDVersion) obj).getValue().equals(this.m_strValue));
    }

    // todo : implement public int hashCode()  - ?

    /**
     * Changed to "public" access type because it will be used by
     * sync4j.dm package.
     *
     *  @return an XML representation of this object
     *	@see sync4j.framework.dm.Node#toXML()
     */
    public String toXML()
    {
        StringBuffer sbXML;
        sbXML = new StringBuffer();
        sbXML.append("<VerDTD>");
        sbXML.append(this.getValue());
        sbXML.append("</VerDTD>\n");
        return sbXML.toString();
    }

}
