/*
 Copyright (c) 2001-2002-2003 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.
 
 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:
 
     "This product includes software developed by the
      sync4j project."
 
 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.
 
 */


package sync4j.framework.core;

import sync4j.framework.core.RepresentationException;
import sync4j.framework.core.xml.*;

/**
 *  corresponds to the &ltData&gt tag in the SyncML represent DTD
 *
 *  @author Sean C. Sullivan
 *  @author Stefano Fornari @ Funambol
 *
 *  @version $Id: Data.java,v 1.4 2003/03/25 21:59:12 stefano_fornari Exp $
 */
public class Data {
    protected String data;
    
    public Data(final String d) {
        this.data = d;
    }
    
    public Data(final long data) {
        this.data = String.valueOf(data);
    }

    /**
     * Creates a Data object from the given element. This implementation just
     * reads the body of the &lt;Data&gt; element as a string. subclasses can
     * overload add additional work in order to extract the right formatted
     * content (i.e. SyncAnchor).
     *
     * @param element the element containing the data
     *
     * @throws RepresentationException if the content is not in the right 
     *         format (more usefull in subclasses)
     */
    public Data(final Element element) throws RepresentationException {
        this(Util.contentAsString(element));
    }
    
    public String getValue() {
        return data;
    }
    
    public String toString() {
        return data;
    }
    
    public String toXML() {
        String s = ((data == null) ? "" : data);
        
        StringBuffer sbXML;
        sbXML = new StringBuffer();
        sbXML.append("<Data>").append(s).append("</Data>\n");
        
        return sbXML.toString();
    }
    
}
