/*
 Copyright (c) 2001-2002 sync4j project
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.

 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.

 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */


package sync4j.framework.core;

import sync4j.framework.core.xml.*;

/**
 *
 *  corresponds to the &ltExec&gt tag in the SyncML represent DTD
 *
 *  @author Sean C. Sullivan
 *  @author Stefano Fonari @ Funambol
 *
 *  @version $Id: ExecCommand.java,v 1.6 2003/12/15 16:55:09 luigiafassina Exp $
 *
 */
public final class ExecCommand extends ModificationCommand
{
    public static String COMMAND_NAME = "Exec";

    private boolean m_bNoResponse;
    private Credential m_cred;

    /**
     *
     *  @param cmdid command identifier. Must be non-null.
     *  @param bNoResponse <b>true</b> if no response is expected.
     *  @param cred authentication credentials. May be null.
     *  @param item parameter must be non-null.
     *
     */
    public ExecCommand(
            final CommandIdentifier cmdid,
            final boolean bNoResponse,
            final Credential cred /* may be null */,
            final Item item /* must be non-null */)
    {
        super(cmdid, new Item[] { item });
        m_bNoResponse = bNoResponse;
        m_cred = cred;
        if (item == null)
        {
            throw new NullPointerException(
                    "Item paremeter is null");
        }
    }

    /**
     *
     *  @param eExec element &ltExec&gt
     *  @throws RepresentationException
     *
     */
    ExecCommand(final Element eExec)
            throws RepresentationException
    {
        // todo : verify that eExec is <Exec>
        this(Util.extractCommandId(eExec, true),
                Util.extractNoResp(eExec, false),
                Util.extractCred(eExec, false),
                Util.extractItem(eExec, true));
    }

    /**
     *
     *  @return true if no response is required
     *
     */
    public boolean getNoResponse()
    {
        return m_bNoResponse;
    }

    /**
     *
     *  @return credential object or null
     *
     */
    public Credential getCredential()
    {
        return m_cred;
    }

    /**
     *
     *  @return an Item object. The return value is guaranteed to be non-null.
     *
     */
    public Item getItem()
    {
        return items[0];
    }

    /**
     *
     *  @return an XML representation of this object
     *
     */
    String toXML()
    {
        StringBuffer sbXML;
        sbXML = new StringBuffer();
        sbXML.append("<Exec>\n");
        sbXML.append(this.getCommandIdentifier().toXML());
        if (this.getNoResponse())
        {
            sbXML.append("<NoResp/>\n");
        }
        if (this.getCredential() != null)
        {
            sbXML.append(this.getCredential().toXML());
        }
        sbXML.append(this.getItem().toXML());
        sbXML.append("</Exec>\n");
        return sbXML.toString();
    }

    public String getName() {
        return ExecCommand.COMMAND_NAME;
    }


}
