/*
 Copyright (c) 2001-2002 sync4j project
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.

 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.

 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */


package sync4j.framework.core;

import sync4j.framework.core.RepresentationException;
import sync4j.framework.core.xml.Element;

/**
 *
 *  corresponds to the &ltExt&gt element in the
 *  SyncML devinf DTD
 *
 *  @author Sean C. Sullivan
 *  @author Stefano Fornari @ Funambol
 *
 *  @version $Id: Extension.java,v 1.3 2003/02/25 10:59:07 stefano_fornari Exp $
 */
public final class Extension
{
    private String m_strName;
    private String[] m_astrValues;

    /**
     *
     *
     *  @param strExtensionName must be non-null. This parameter
     *                  corresponds to the &ltXNam&gt element
     *                  in the SyncML specification.
     *  @param astrExtensionValues zero or more String's. This
     *                  parameter corresponds to the &ltXVal&gt
     *                  element in the SyncML specification.
     *                  This parameter must be non-null.
     *                  The elements of this array must be non-null.
     *
     *  @throws java.lang.NullPointerException
     *
     */
    public Extension(
            final String strExtensionName,
            final String[] astrExtensionValues)
    {
        if (strExtensionName == null)
        {
            throw new NullPointerException(
                    "strExtensionName parameter is null");
        }
        if (astrExtensionValues == null)
        {
            throw new NullPointerException(
                    "astrExtensionValues parameter is null");
        }

        m_strName = strExtensionName;
        m_astrValues = (String[]) astrExtensionValues.clone();

        // validate array contents
        for (int i = 0; i < m_astrValues.length; i++)
        {
            if (m_astrValues[i] == null)
            {
                throw new NullPointerException(
                        "Extension values array parameter contains a null value at index "
                        + i);
            }
        }
    }

    /**
     *
     *   @param eExt element &ltExt&gt
     *
     *
     */
    Extension(final Element eExt)
            throws RepresentationException
    {
        // todo : verify that eExt is <Ext> - ?
        this(Util.extractXNam(eExt, true),
                Util.extractXVals(eExt, false));
    }

    /**
     *
     *  @return the name of the extension. The return value is guaranteed to be non-null.
     *
     */
    public String getName()
    {
        return m_strName;
    }

    /**
     *
     *  @return an array of extension values. The return value is guaranteed to be non-null.
     *
     */
    public String[] getValues()
    {
        return (String[]) m_astrValues.clone();
    }

    /**
     *
     *
     *  @return an XML representation of this object
     *
     *
     */
    String toXML()
    {
        StringBuffer sbXML;
        sbXML = new StringBuffer();
        sbXML.append("<Ext>\n");
        sbXML.append("<XNam>");
        sbXML.append(this.getName());
        sbXML.append("</XNam>\n");
        for (int i = 0; i < m_astrValues.length; i++)
        {
            sbXML.append("<XVal>");
            sbXML.append(m_astrValues[i]);
            sbXML.append("</XVal>\n");
        }
        sbXML.append("</Ext>\n");
        return sbXML.toString();
    }

}
