/*
 Copyright (c) 2001-2002 sync4j project
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.

 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.

 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */


package sync4j.framework.core;

import sync4j.framework.core.xml.*;

/**
 *
 *  corresponds to the &ltGet&gt tag in the SyncML represent DTD
 *
 *  @author Sean C. Sullivan
 *  @author Stefano Fornari @ Funambol
 *
 *  @version $Id: GetCommand.java,v 1.5 2003/12/15 16:55:09 luigiafassina Exp $
 */
public final class GetCommand extends ItemizedCommand
{
    public static String COMMAND_NAME = "Get";

    private boolean m_bNoResponse;
    private String m_strLanguage;
    private Credential m_cred;

    /**
     *
     *  @param cmdid command identifier. Must be non-null.
     *  @param bNoResponse <b>true</b> if no response is expected.
     *  @param strLanguage language. This parameter may be null.
     *  @param cred authentication credentials. May be null.
     *  @param m meta data. May be null.
     *  @param items array. Must be non-null. Length of array must be greater than zero.
     *                      Elements of the array must be non-null.
     *
     */
    public GetCommand(
            final CommandIdentifier cmdid,
            final boolean bNoResponse,
            final String strLanguage /* may be null */,
            final Credential cred /* may be null */,
            final Meta m /* may be null */,
            final Item[] items)
    {
        super(cmdid, m, items);

        if (items == null)
        {
            throw new NullPointerException(
                    "items array parameter is null");
        }
        else if (items.length < 1)
        {
            throw new IllegalArgumentException(
            "items parameter: array length is < 1");
        }

        m_bNoResponse = bNoResponse;
        m_strLanguage = strLanguage;
        m_cred = cred;
    }

    /**
     *
     *
     *  @param eGet must be non-null
     *
     *
     */
    GetCommand(final Element eGet)
            throws RepresentationException
    {
        // todo : verify that eGet is <Get>
        this(Util.extractCommandId(eGet, true),
                Util.extractNoResp(eGet, false),
                Util.extractLang(eGet, false),
                Util.extractCred(eGet, false),
                Util.extractMeta(eGet, false),
                Util.extractItems(eGet, true));
    }

    /**
     *
     *  @return true if no response is required
     *
     *
     */
    public boolean getNoResponse()
    {
        return m_bNoResponse;
    }

    /**
     *
     *  @return may return null
     *
     */
    public String getLanguage()
    {
        return m_strLanguage;
    }

    /**
     *
     *  @return may return null
     *
     */
    public Credential getCredential()
    {
        return m_cred;
    }

    /**
     *
     *  @return an XML representation of this object
     *
     */
    String toXML()
    {
        StringBuffer sbXML;
        sbXML = new StringBuffer();
        sbXML.append("<Get>\n");
        sbXML.append(this.getCommandIdentifier().toXML());
        if (this.getNoResponse())
        {
            sbXML.append("<NoResp/>\n");
        }
        if (this.getLanguage() != null)
        {
            sbXML.append("<Lang>");
            sbXML.append(this.getLanguage());
            sbXML.append("</Lang>\n");
        }
        if (this.getCredential() != null)
        {
            sbXML.append(this.getCredential().toXML());
        }
        if (this.getMeta() != null)
        {
            sbXML.append(this.getMeta().toXML());
        }
        for (int i = 0; i < items.length; i++)
        {
            sbXML.append(items[i].toXML());
        }
        sbXML.append("</Get>\n");
        return sbXML.toString();
    }

        public String getName() {
            return GetCommand.COMMAND_NAME;
        }

}
