/*
 Copyright (c) 2001-2002-2003 sync4j project
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.

 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.

 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */


package sync4j.framework.core;

import sync4j.framework.core.xml.*;

/**
 *
 *  corresponds to the &ltItem&gt tag in the SyncML represent DTD
 *
 *  @author Sean C. Sullivan
 *  @author Stefano Fornari @ Funambol
 *
 *  @version $Id: Item.java,v 1.5 2003/11/05 11:44:38 luigiafassina Exp $
 */
public final class Item
{
    private Target m_target;
    private Source m_source;
    private Meta m_meta;
    private Data m_data;

    /**
     *
     *  According to the SyncML spec, &ltItem&gt "specifies a container for item data"
     *
     *  @param t may be null
     *  @param src may be null
     *  @param meta may be null
     *  @param d may be null
     *
     */
    public Item(
            final Target t,
            final Source src,
            final Meta meta,
            final Data d)
    {
        m_target = t;
        m_source = src;
        m_meta = meta;
        m_data = d;
    }

    /**
     *
     *  @param eItem must be non-null
     *
     */
    Item(final Element eItem)
            throws RepresentationException
    {
        // todo : verify that eItem is an <Item>
        this(Util.extractTarget(eItem, false),
                Util.extractSource(eItem, false),
                Util.extractMeta(eItem, false),
                Util.extractData(eItem, false));
    }

    /**
     *
     * @return may return null
     *
     */
    public Target getTarget()
    {
        return m_target;
    }

    /**
     *
     * @return may return null
     *
     */
    public Source getSource()
    {
        return m_source;
    }

    /**
     *
     * @return may return null
     *
     */
    public Meta getMeta()
    {
        return m_meta;
    }

    /**
     *
     * @return may return null
     *
     */
    public Data getData()
    {
        return m_data;
    }

    public void setData(Data data) {
        this.m_data = data;
    }
    
    /**
     *
     *   @return an XML representation of this object
     *
     */
    String toXML()
    {
        StringBuffer sbXML;
        sbXML = new StringBuffer();
        sbXML.append("<Item>\n");
        if (this.getTarget() != null)
        {
            sbXML.append(this.getTarget().toXML());
        }
        if (this.getSource() != null)
        {
            sbXML.append(this.getSource().toXML());
        }
        if (this.getMeta() != null)
        {
            sbXML.append(this.getMeta().toXML());
        }
        if (this.getData() != null)
        {
            sbXML.append(this.getData().toXML());
        }
        sbXML.append("</Item>\n");
        return sbXML.toString();
    }

}
