/*
 Copyright (c) 2001-2002 sync4j project
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.

 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.

 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */


package sync4j.framework.core;


import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;

import sync4j.framework.tools.Base64;

/**
 *
 *  Implements the MD-5 authentication scheme.  Since J2ME environment 
 *  has limited memory space, instead of relying on the 
 *  <code>java.security</code> library, we include only the necessary
 *  classes from <a href="http://www.bouncycastle.org">bouncycastle</a>.
 *  Since the changes are quite localized, so we skipped the hassle of
 *  creating an adapter for the bouncycastle library and the
 *  <code>java.security</code> library.
 *
 *  @author Sean C. Sullivan
 *  @author Stefano Fornari @ Funambol
 * 
 *  @see    BasicAuthentication
 *  @see    Credential
 *
 *  @version $Id: MD5Authentication.java,v 1.3 2003/02/25 10:59:07 stefano_fornari Exp $
 */
public final class MD5Authentication extends Authentication
{
    private static String TYPE = "syncml:auth-md5";
    private static String FORMAT_BASE64 = "b64";
    private NextNonce m_nextNonce;

    /**
     *
     *  @param strUsername username. Must be non-null.
     *  @param strPassword password. Must be non-null.
     *  @param n nonce value
     *
     */
    public MD5Authentication(
            final String strUsername,
            final String strPassword,
            final NextNonce n)
    {
        super(createData(strUsername, strPassword, n));
        m_nextNonce = n;
        // todo : check for null nonce value???
    }

    private static String createData(
            final String strUsername,
            final String strPassword,
            final NextNonce n)
    {

        if (strUsername == null)
        {
            throw new NullPointerException("username parameter is null");
        }
        if (strPassword == null)
        {
            throw new NullPointerException("password parameter is null");
        }

        String strResult = null;

        try {
            MessageDigest md = MessageDigest.getInstance("MD5");

            byte[] bytes = 
                    (strUsername
                    + ":"
                    + strPassword
                    + ":"
                    + n.getValue()).getBytes();

            md.update(bytes);

            byte[] resBuf = md.digest();

            strResult = new String(Base64.encode(resBuf));
        } catch (NoSuchAlgorithmException e) {
            return null;
        }

        return strResult;
    }

    public String getType()
    {
        return MD5Authentication.TYPE;
    }

    public String getFormat()
    {
        return MD5Authentication.FORMAT_BASE64;
    }

    /**
     *
     *  @return may return a null value (? TODO - is this correct ? )
     *
     */
    public NextNonce getNextNonce()
    {
        return m_nextNonce;
    }

}
