/*
 Copyright (c) 2001-2003 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.  
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */


package sync4j.framework.core;

import sync4j.framework.core.RepresentationException;
import sync4j.framework.core.xml.Element;

/**
 * This class represents an <i>anchor</i> meta content (see SyncML
 * specification).
 *
 * @author  Stefano Fornari @ Funambol
 *
 * @version $Id: MemMetaContent.java,v 1.2 2003/12/15 16:55:09 luigiafassina Exp $
 *
 */
public final class MemMetaContent extends MetaContent
{    
    /**
     * Creates an <i>AnchorMetaContent</i> object from a jdom Element object.
     *
     * @param memInfo the xml element
     *
     * @throws RepresentationException;
     */
    MemMetaContent(final Element memInfo) throws RepresentationException
    {
        super(new MemoryInfo(memInfo));
    }
            
    /**
     * In this case the XML version of the content is just the string itself.
     *
     * @return the content string;
     */
    public String toXML() {
        return ((MemoryInfo)content).toXML();
    }
    
    /**
     * Calls toXML()
     *
     * @return a readable version of the object
     */
    public String toString() {
        return toXML();
    }
    
    public String getContentTag() {
        return "Mem";
    }
}
