/*
 Copyright (c) 2001-2003 sync4j project
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.

 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.

 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.
 */


package sync4j.framework.core;

import java.util.*;

import sync4j.framework.core.RepresentationException;
import sync4j.framework.core.xml.Element;

/**
 *
 *  corresponds to the &ltSyncML&gt element in the SyncML represent DTD
 *
 *  @author Sean C. Sullivan
 *  @author Stefano Fornari @ Funambol
 *
 *  @version $Id: Message.java,v 1.10 2003/12/15 16:55:09 luigiafassina Exp $
 *
 *
 */
public final class Message
{
    private SyncHeader header       ;
    private SyncBody   body         ;
    private boolean    lastMessage  ;


    /**
     *
     *  @param strXMLFragment must be non-null
     *
     *  @throws RepresentationException
     *
     *
     */
    public Message(final String strXMLFragment)
            throws RepresentationException {
        this(Util.toElement(strXMLFragment, "SyncML"));
    }

    /**
     *
     * @param root must be non-null
     *
     */
    Message(final Element root)
            throws RepresentationException {
        this(Util.extractSyncHeader(root),
             Util.extractSyncBody(root)  ,
             false                       );

        int numChildren = 0;
        for (Enumeration enum = root.getChildren(); enum.hasMoreElements();)
        {
            enum.nextElement();
            numChildren ++;
        }
        if (numChildren != 2)
        {
            throw new RepresentationException( "A message must have two elements"
                                             + " (current: "
                                             + numChildren
                                             + ")"
                                             );
        }
    }

    /**
     *
     *  @param header must be non-null
     *  @param body must be non-null
     *  @param last is the last message of a syncsession?
     *
     *  @throws RepresentationException
     *
     *
     */
    public Message(final SyncHeader header,
                   final SyncBody   body  ,
                   final boolean    last  )
    throws RepresentationException {
        if (header == null) {
            throw new RepresentationException("SyncHeader is null");
        }
        if (body == null)
        {
            throw new RepresentationException("SyncBody is null");
        }
        this.header        = header;
        this.body          = body  ;
        this.lastMessage   = last  ;
    }
    
    /**
     *
     *  @param header must be non-null
     *  @param body must be non-null
     *
     *  @throws RepresentationException
     *
     *
     */
    public Message(final SyncHeader header,
                   final SyncBody   body  )
    throws RepresentationException {
        this(header, body, false);
    }
        
    

    /**
     *
     * @return the return value is guaranteed to be non-null
     *
     */
    public SyncHeader getHeader()
    {
        return header;
    }

    /**
     *
     * @return the return value is guaranteed to be non-null
     *
     */
    public SyncBody getBody()
    {
        return body;
    }
    
    /**
     * 
     */
    public boolean isLastMessage() {
        return lastMessage;
    }
    
    /**
     *
     */
    public void setLastMessage(boolean lastMessage) {
        this.lastMessage = lastMessage;
    }

    /**
     *
     * @return an XML representation of this object
     *
     */
    public String toXML()
    {
        StringBuffer sbXML;
        sbXML = new StringBuffer();
        sbXML.append("<SyncML>\n");
        sbXML.append(header.toXML());
        sbXML.append(body.toXML());
        sbXML.append("</SyncML>\n");
        return sbXML.toString();
    }

    public String toString() {
        return toXML();
    }

    // --------------------------------------------------------- Private methods

}
