/*
 Copyright (c) 2001-2002 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.
 
 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:
 
     "This product includes software developed by the
      sync4j project."
 
 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.
 
 */


package sync4j.framework.core;

import java.util.Enumeration;

import sync4j.framework.core.xml.*;

/**
 *
 *  corresponds to the &ltMeta&gt tag defined in the
 *  SyncML respresent DTD
 *
 *  @author Sean C. Sullivan
 *  @author Stefano Fornari @ Funambol
 *
 *  @version  $Id: Meta.java,v 1.5 2003/12/15 16:55:09 luigiafassina Exp $
 *
 */
public final class Meta {
    
    // --------------------------------------------------------------- Constants    
    public static final String META_FORMAT  = "Format";
    public static final String META_TYPE    = "Type"  ;
    
    // ---------------------------------------------------------- Public methods    
    private MetaContent value;
    private MetaContent mcFormat;
    
    public Meta(final MetaContent value) {
        this.value = value;
    }
    
    /**
     * @param mcType   MetaContent with value of tag Type
     * @param mcFormat MetaContent with value of tag Format
     */
    public Meta(final MetaContent mcType, final MetaContent mcFormat) {
        this.value = mcType;
        this.mcFormat = mcFormat;
    }
    
    /**
     *
     * @param eMeta must be non-null
     *
     */
    Meta(final Element eMeta)
    throws RepresentationException {        
        Enumeration children = eMeta.getChildren();
        
        Element element = null;
        String  name    = null;
        for (; (children != null) && (children.hasMoreElements());) {
            element = (Element)children.nextElement();
            name    = element.getName();

            if (name.equalsIgnoreCase(META_TYPE)) {
                value = MetInfUtil.extractMetInf(element);
            } else if (name.equalsIgnoreCase(META_FORMAT)) {
                mcFormat = MetInfUtil.extractMetInf(element);
            } else {
                value = MetInfUtil.extractMetInf(element);
            }
        }
        new Meta(value, mcFormat);
        
    }
  
    /**
     * @return format the value of format that may be null
     */
    public MetaContent getFormat() {
        return mcFormat;
    }
    
    /**
     *
     * @return value
     *
     */
    public MetaContent getValue() {
        return value;
    }
        
    public String toString() {
        return value.toString();
    }
    
    public boolean isTypeContent() {
        return META_TYPE.equals(value.getContentTag());
    }
    
    /**
     *
     * @return an XML representation of this object
     *
     */
    String toXML() {
        StringBuffer sbXML;
        sbXML = new StringBuffer();
        sbXML.append("<Meta>");
        sbXML.append(value.toXML());
        if (mcFormat != null) {
            sbXML.append(mcFormat.toXML());
        }
        sbXML.append("</Meta>\n");
        return sbXML.toString();
    }
    
}
