/*

 Copyright (c) 2001-2002 sync4j project
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.

 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.

 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */


package sync4j.framework.core;

import sync4j.framework.core.RepresentationException;
import sync4j.framework.core.xml.Element;

import sync4j.framework.tools.Base64;

/**
 *
 *  corresponds to &ltNextNonce&gt tag
 *  <br>
 *  <br>
 *  From the spec:
 *  <pre>
 *  "Specifies the nonce string to be used in any subsequent
 *   communication. [...]"
 *  </pre>
 *
 *  @author Sean C. Sullivan
 *  @author Stefano Fornari @ Funambol
 *
 *  @version $Id: NextNonce.java,v 1.5 2003/02/25 10:59:07 stefano_fornari Exp $
 */
public final class NextNonce
{
    private String m_strValue;

    /**
     *
     *  @param strValue must be non-null
     *  @param bBase64Encoded true if 'strValue' is already Base64 encoded
     *
     */
    public NextNonce(
            final String strValue,
            final boolean bBase64Encoded)
    {
        // todo : utilize the boolean parameter
        this.m_strValue = strValue;
        if (m_strValue == null)
        {
            throw new NullPointerException("strValue parameter is null");
        }
    }

    /**
     *
     * @param eNextNonce must be non-null
     *
     */
    NextNonce(final Element eNextNonce)
            throws RepresentationException
    {
        // todo : code here
        this("", true);
    }

    /**
     *
     * @return value
     *
     */
    public String getValue()
    {
        return m_strValue;
    }

    /**
     *
     * @return the value in Base64 encoded form
     *
     */
    public String getValueAsBase64()
    {
        byte[] encoded = Base64.encode(m_strValue.getBytes());
        return new String(encoded);
    }

    public String toString()
    {
        return m_strValue;
    }


    /**
     *
     *  @return an XML representation of this object
     *
     */
    String toXML()
    {
        StringBuffer sbXML = new StringBuffer();
        sbXML.append("<NextNonce>");
        sbXML.append(this.getValueAsBase64());
        sbXML.append("</NextNonce>");
        return sbXML.toString();
    }
}
