/*
 Copyright (c) 2001 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.  
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */


package sync4j.framework.core;

/**
  *
  * a SyncML package
  * <br>
  * <br>
  * From syncml_represent_v101_20010615.pdf:
  * <br>
  * <pre>
  *
  * "In SyncML, the data synchronization operations are
  *  conceptually bounded into a SyncML Package. The SyncML
  *  Package is just a conceptual frame for one or more
  *  SyncML Messages that are required to convey a set of
  *  data synchronization semantics. [...]"
  *
  * </pre>
  *
  *
  *  @author Sean C. Sullivan
  *  @author Stefano Fornari @ Funambol
  *
  * 
  *  @version $Id: Package.java,v 1.3 2003/12/15 16:55:09 luigiafassina Exp $
  */
public final class Package
// todo : determine if this class is worth keeping in the sync4j API
{
    private Message[] m_msgs;

    public Package(final Message[] msgs)
    {
	m_msgs = (Message[]) msgs.clone();
	if (m_msgs.length < 1)
	{
		throw new IllegalArgumentException(
		  "Message[] array length is < 1");
	}
	for (int i = 0; i < m_msgs.length; i++)
	{
		if (m_msgs[i] == null)
		{
		  throw new NullPointerException(
		     "null array element: Message[" + i + "]");
		}
	}
    }

    public Message[] getMessages()
    {
	return (Message[]) m_msgs.clone();
    }
}
