/*
 Copyright (c) 2001-2002 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.
 
 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:
 
     "This product includes software developed by the
      sync4j project."
 
 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.
 
 */


package sync4j.framework.core;

import sync4j.framework.core.xml.*;

/**
 *
 *  corresponds to &ltResults&gt tag in SyncML represent DTD
 *
 *  @author Sean C. Sullivan
 *  @author Stefano Fornari @ Funambol
 *
 *  @version $Id: ResultsCommand.java,v 1.4 2003/04/19 17:45:42 stefano_fornari Exp $
 */
public final class ResultsCommand extends ResponseCommand {
    public static String COMMAND_NAME = "Results";
    
    protected Meta meta;
    
    /**
     *
     * @param cmdid command identifier. Must be non-null.
     * @param strReferenceMessageID may be null. If non-null, String length must be greater than zero.
     * @param strCommandRef must be non-null. If non-null, String length must be greater than zero.
     * @param m meta information. May be null.
     * @param tref may be null.
     * @param sref may be null.
     * @param items This parameter must be non-null. The array length must be greater than zero.
     *          The array elements must be non-null.
     *
     * @throws java.lang.IllegalArgumentException
     *
     */
    public ResultsCommand(
    final CommandIdentifier cmdid /* <CmdID> */,
    final String strReferenceMessageID /* <MsgRef> */,
    final String strCommandRef /* <CmdRef> */,
    final Meta m /* <Meta> */,
    final TargetRef tref /* <TargetRef> */,
    final SourceRef sref /* <SourceRef> */,
    final Item[] items /* one or more <Item> elements */) {
        super(cmdid,
        strReferenceMessageID,
        strCommandRef,
        new TargetRef[] { tref },
        new SourceRef[] { sref },
        items);
        meta = m;
    }
    
    /**
     *
     * @param eResults must be non-null
     *
     */
    ResultsCommand(final Element eResults)
    throws RepresentationException {
        this(Util.extractCommandId(eResults, true),
        Util.extractMessageRef(eResults, false),
        Util.extractCommandRef(eResults, true),
        Util.extractMeta(eResults, false),
        Util.extractTargetRef(eResults, false),
        Util.extractSourceRef(eResults, false),
        Util.extractItems(eResults, true));
    }
    
    /**
     *
     *  @return may return null
     *
     */
    public String getReferenceMessageID() {
        return strReferenceMessageID;
    }
    
    /**
     *
     *  @return may return null
     *
     */
    public Meta getMeta() {
        return meta;
    }
    
    /**
     *
     *  @return may return null
     *
     */
    public TargetRef getTargetRef() {
        return targetRefs[0];
    }
    
    /**
     *
     *  @return may return null
     *
     */
    public SourceRef getSourceRef() {
        return sourceRefs[0];
    }
    
    /**
     *
     * @return an XML representation of this object
     *
     */
    String toXML() {
        StringBuffer sbXML = new StringBuffer();
        sbXML.append("<Results>");
        sbXML.append(this.getCommandIdentifier().toXML());
        if (this.getReferenceMessageID() != null) {
            sbXML.append("<MsgRef>");
            sbXML.append(this.getReferenceMessageID().toString());
            sbXML.append("</MsgRef>\n");
        }
        sbXML.append("<CmdRef>");
        sbXML.append(this.getCommandRef().toString());
        sbXML.append("</CmdRef>\n");
        if (this.getMeta() != null) {
            sbXML.append(this.getMeta().toXML());
        }
        if (this.getTargetRef() != null) {
            sbXML.append(this.getTargetRef().toXML());
        }
        if (this.getSourceRef() != null) {
            sbXML.append(this.getSourceRef().toXML());
        }
        for (int i = 0; i < items.length; i++) {
            sbXML.append(items[i].toXML());
        }
        sbXML.append("</Results>\n");
        return sbXML.toString();
    }
    
    public String getName() {
        return ResultsCommand.COMMAND_NAME;
    }
    
}
