/*
 Copyright (c) 2001 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.
 
 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:
 
     "This product includes software developed by the
      sync4j project."
 
 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.
 
 */


package sync4j.framework.core;

import sync4j.framework.core.xml.*;

/**
 *
 *  corresponds to the &ltSource&gt element in the SyncML represent DTD
 *
 *  @author Sean C. Sullivan
 *  @author Stefano Fornari @ Funambol
 *
 *  @version $Id: Source.java,v 1.8 2004/01/14 08:03:50 luigiafassina Exp $
 */
public final class Source {
    /**
     * Specifies the target or source specific address
     */
    private String m_locURI;
    
    /**
     * Specifies the display name for the target or source address
     */
    private String m_strLocName;
    
    // todo : re-evaluate this class
    
    // -------------------------------------------------------- Constructors
    
    public Source(
    final String locURI,
    final String strLocName) {
        m_locURI = locURI;
        m_strLocName = strLocName;
        if (m_locURI == null) {
            throw new NullPointerException(
            "URI parameter is null");
        }
    }
    
    public Source(final String locURI) {
        this(locURI, null);
    }
    
    Source(final Element eSource)
    throws RepresentationException {
        // todo : verify that eSource is a <Source> tag
        this( Util.extractLocURI(eSource, true),
        Util.extractLocName(eSource, false));
    }
    
    // ------------------------------------------------------ Public methods
    
    /**
     * Returns the target or source specific address
     *
     * @return the target or source specific address
     */
    public String getURI() {
        return m_locURI;
    }
    
    public void setURI(String uri) {
        this.m_locURI = uri;
    }
    
    /**
     * Returns the display name for the target or source address
     *
     *  @return the display name for the target or source address
     *
     */
    public String getLocationName() {
        return m_strLocName;
    }
    
    /**
     * Returns the XML representation of a Source object
     *
     * @return the XML representation of a Source object
     */
    public String toXML() {
        StringBuffer sbXML;
        sbXML = new StringBuffer();
        sbXML.append("<Source>\n");
        sbXML.append("<LocURI>");
        sbXML.append(this.m_locURI);
        sbXML.append("</LocURI>\n");
        if (m_strLocName != null) {
            sbXML.append("<LocName>");
            sbXML.append(this.m_strLocName);
            sbXML.append("</LocName>\n");
        }
        sbXML.append("</Source>\n");
        return sbXML.toString();
    }
    
    /**
     * @return a string representation of this Source for debugging purposes
     */
    public String toString() {
		StringBuffer sb = new StringBuffer();
		sb.append("locURI:" + m_locURI);
        sb.append("locName:" + m_strLocName);
		return sb.toString();
    }
}
