/*
 Copyright (c) 2001 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.
 
 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:
 
     "This product includes software developed by the
      sync4j project."
 
 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.
 
 */


package sync4j.framework.core;

import sync4j.framework.core.xml.*;

/**
 * <pre>
 * note:  the &ltSourceRef&gt element is declared in 2 DTD's:
 * 1) the devinfo DTD
 * 2) the represent DTD
 * </pre>
 *
 *
 *  @author Sean C. Sullivan
 *  @author Stefano Fornari @ Funambol
 *
 *  @version $Id: SourceRef.java,v 1.4 2003/12/15 16:55:09 luigiafassina Exp $
 *
 */

// todo : possibly eliminate this class and replace usage with String
public final class SourceRef {
    private String value;
    
    public SourceRef(final String s) {
        if (s == null) {
            throw new IllegalArgumentException("source cannot be null");
        }
        value = s;
        // todo : verify that value is non-null
    }
    
    /**
     * A <i>TargetRef</i> from an existing target.
     *
     * @param source the source to extract the reference from - NOT NULL
     *
     */
    public SourceRef(final Source source) {
        this(source.getURI());
    }
    
    SourceRef(final Element eSourceRef)
    throws RepresentationException {
        this(eSourceRef.getText());
    }
    
    public String getValue() {
        return value;
    }
    
    public String toString() {
        return value;
    }
    
    String toXML() {
        StringBuffer sbXML;
        sbXML = new StringBuffer();
        sbXML.append("<SourceRef>");
        sbXML.append(this.getValue());
        sbXML.append("</SourceRef>\n");
        return sbXML.toString();
    }
    
}
