/*
 Copyright (c) 2001-2002 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.
 
 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:
 
     "This product includes software developed by the
      sync4j project."
 
 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.
 
 */


package sync4j.framework.core;

import sync4j.framework.core.xml.*;

/**
 *
 *  corresponds to &ltStatus&gt tag in SyncML represent DTD
 *
 *  @author Sean C. Sullivan
 *  @author Stefano Fornari @ Funambol
 *
 *  @version $Id: StatusCommand.java,v 1.6 2003/04/19 17:45:42 stefano_fornari Exp $
 *
 */
public final class StatusCommand
extends ResponseCommand {
    
    public static String COMMAND_NAME = "Status";
    
    private Credential              cred       ;
    private AuthenticationChallenge chal       ;
    private Data                    data       ;
    private String                  commandName;
    
    /**
     *
     * @param cmdid command identifier. Must be non-null.
     * @param strReferenceMessageID Must be non-null. Also, String length must be greater than zero.
     * @param strCommandRef Must be non-null. Also, String length must be greater than zero.
     * @param strCommandName Must be non-null. Also, String length must be greater than zero.
     * @param targetRefs Array length may be zero. Array elements must be non-null.
     *                   If null a TargetRef[0] is used
     * @param sourceRefs Array length may be zero. Array elements must be non-null.
     *                   If null a SourceRef[0] is used
     * @param cred authentication credentials. May be null.
     * @param chal may be null.
     * @param d Must be non-null.
     * @param items Must be non-null. Array length may be zero.
     *          Array elements must be non-null.
     *
     */
    public StatusCommand(
    final CommandIdentifier cmdid /* <CmdID> */,
    final String strReferenceMessageID /* <MsgRef> */,
    final String strCommandRef /* <CmdRef> */,
    final String strCommandName /* todo : is this right? */,
    final TargetRef[] targetRefs,
    final SourceRef[] sourceRefs,
    final Credential cred /* <Cred> */,
    final AuthenticationChallenge chal /* <Chal> */,
    final Data d /* <Data> */,
    final Item[] items /* zero or more <Item> elements */) {
        super(cmdid,
        strReferenceMessageID,
        strCommandRef,
        (targetRefs == null) ? new TargetRef[0] : targetRefs,
        (sourceRefs == null) ? new SourceRef[0] : sourceRefs,
        items);
        
        if (d == null) {
            throw new NullPointerException(
            "Data parameter is null");
        }
        
        if (strCommandName == null) {
            throw new NullPointerException("CommandName parameter is null");
        }
        
        this.commandName = strCommandName;
        this.data        = d             ;
        this.cred        = cred          ;
        this.chal        = chal          ;
    }
    
    /**
     * The same as the previouse constructor, but accepting <i>targetRefs</i>
     * and <i>sourceRefs</i> as String instead of String[].
     *
     * @param cmdid command identifier. Must be non-null.
     * @param strReferenceMessageID Must be non-null. Also, String length must be greater than zero.
     * @param strCommandRef Must be non-null. Also, String length must be greater than zero.
     * @param strCommandName Must be non-null. Also, String length must be greater than zero.
     * @param targetRef if null a TargetRef[0] is created
     * @param sourceRef if null a SourceRef[0] is created
     * @param cred authentication credentials. May be null.
     * @param chal may be null.
     * @param d Must be non-null.
     * @param items Must be non-null. Array length may be zero.
     *          Array elements must be non-null.
     *
     */
    public StatusCommand(
    final CommandIdentifier cmdid /* <CmdID> */,
    final String strReferenceMessageID /* <MsgRef> */,
    final String strCommandRef /* <CmdRef> */,
    final String strCommandName /* todo : is this right? */,
    final TargetRef targetRef,
    final SourceRef sourceRef,
    final Credential cred /* <Cred> */,
    final AuthenticationChallenge chal /* <Chal> */,
    final Data d /* <Data> */,
    final Item[] items /* zero or more <Item> elements */) {
        this( cmdid                            ,
              strReferenceMessageID            ,
              strCommandRef                    ,
              strCommandName                   ,
              (targetRef == null)              ?
                  new TargetRef[0]             :
                  new TargetRef[] { targetRef },
              (sourceRef == null)              ?
                  new SourceRef[0]             :
                  new SourceRef[] { sourceRef },
              cred                             ,
              chal                             ,
              d                                ,
              items
            );
    }
    
    /**
     *
     * @param eStatus must be non-null
     *
     */
    StatusCommand(final Element eStatus)
    throws RepresentationException {
        // todo : verify that eStatus is <Status> - ?
        this(Util.extractCommandId(eStatus, true),
        Util.extractMessageRef(eStatus, true),
        Util.extractCommandRef(eStatus, true),
        Util.extractCommandName(eStatus, true),
        Util.extractTargetRefs(eStatus, false),
        Util.extractSourceRefs(eStatus, false),
        Util.extractCred(eStatus, false),
        Util.extractChal(eStatus, false),
        Util.extractData(eStatus, true),
        Util.extractItems(eStatus, false));
    }
    
    /**
     *
     * @return may return null
     *
     */
    public Credential getCredential() {
        return cred;
    }
    
    /**
     *
     * @return may return null
     *
     */
    public AuthenticationChallenge getAuthenticationChallenge() {
        return chal;
    }
    
    /**
     *
     * @return The return value is guaranteed to be non-null.
     *
     */
    public Data getData() {
        return data;
    }
    
    public String getCommandName() {
        return commandName;
    }
    
    /**
     *
     * @return an XML representation of this object
     *
     */
    String toXML() {
        StringBuffer sbXML;
        sbXML = new StringBuffer();
        sbXML.append("<Status>\n");
        sbXML.append(this.getCommandIdentifier().toXML());
        sbXML.append("<MsgRef>");
        sbXML.append(this.getReferenceMessageID());
        sbXML.append("</MsgRef>\n");
        sbXML.append("<CmdRef>");
        sbXML.append(this.getCommandRef());
        sbXML.append("</CmdRef>\n");
        sbXML.append("<Cmd>");
        sbXML.append(this.getCommandName());
        sbXML.append("</Cmd>\n");
        
        for (int i = 0; (i < targetRefs.length); i++) {
            if (targetRefs[i] != null) {
                sbXML.append(targetRefs[i].toXML());
            }
        }
        for (int i = 0; (i < sourceRefs.length); i++) {
            if (sourceRefs[i] != null) {
                sbXML.append(sourceRefs[i].toXML());
            }
        }
        if (this.getCredential() != null) {
            sbXML.append(this.getCredential().toXML());
        }
        if (this.getAuthenticationChallenge() != null) {
            sbXML.append(this.getAuthenticationChallenge().toXML());
        }
        sbXML.append(this.getData().toXML());
        for (int i = 0; (i < items.length); i++) {
            sbXML.append(items[i].toXML());
        }
        sbXML.append("</Status>\n");
        return sbXML.toString();
    }
    
    public String getName() {
        return StatusCommand.COMMAND_NAME;
    }
}
