/*
 Copyright (c) 2001-2002 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.
 
 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:
 
     "This product includes software developed by the
      sync4j project."
 
 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.
 
 */


package sync4j.framework.core;

import sync4j.framework.core.RepresentationException;
import sync4j.framework.core.xml.Element;

/**
 *
 *  corresponds to the &ltAnchor&gt tag in the metainfo spec
 *
 *  @author Sean C. Sullivan
 *  @author Stefano Fornari @ Funambol
 *  @see    MetaInfo
 *
 *  @version $Id: SyncAnchor.java,v 1.7 2004/01/14 08:03:50 luigiafassina Exp $
 */
public final class SyncAnchor {

    private String last;
    private String next;
    
    /**
     *
     * @param last may be null
     * @param next Must be non-null.
     *
     */
    public SyncAnchor(final String last, final String next) {
        // last can be null
        this.last = last;
        // next cannot be null
        if ((null == next) || (next.length() == 0)) {
            throw new IllegalArgumentException("'next' parameter is null or empty");
        }
        this.next = next;
    }
    
    /**
     *
     * @param eAnchor must be non-null
     *
     */
    SyncAnchor(final Element eAnchor)
    throws RepresentationException {
        // todo : verify that eAnchor is <Anchor>  -  ?
        this(Util.extractLast(eAnchor, false),
        Util.extractNext(eAnchor, true));
    }
    
    /**
     *
     * @return This method may return null.
     *
     */
    public String getLast() {
        return last;
    }
    
    /**
     *
     * @return This method is guaranteed to return a non-null value.
     *
     */
    public String getNext() {
        return next;
    }
    
    /**
     *
     * @return an XML representation of this object
     *
     */
    String toXML() {
        StringBuffer sbXML;
        sbXML = new StringBuffer();
        sbXML.append("<Anchor xmlns='" + Constants.NAMESPACE_METINF.getURI() + "'>\n");
        if (this.getLast() != null) {
            sbXML.append("<Last>");
            sbXML.append(this.getLast());
            sbXML.append("</Last>\n");
        }
        sbXML.append("<Next>");
        sbXML.append(this.getNext());
        sbXML.append("</Next>\n");
        sbXML.append("</Anchor>\n");
        return sbXML.toString();
    }

    /**
     * @return a string representation of this SyncAnchor for debugging purposes
     */
    public String toString() {
		StringBuffer sb = new StringBuffer();
		sb.append("last:" + last);
        sb.append("next:" + next);
		return sb.toString();
    }
}
