/*
 Copyright (c) 2001-2003 sync4j project
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.

 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.

 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */


package sync4j.framework.core;

import sync4j.framework.core.RepresentationException;
import sync4j.framework.core.xml.Element;

/**
 *
 *  synchronization capabilities of a datastore.
 *
 *  this class corresponds to the &ltSyncCap&gt tag in the
 *  SyncML devinf DTD
 *
 *  @see DataStore
 *  @author Sean C. Sullivan
 *  @author Stefano Fornari @ Funambol
 *
 *  @version $Id: SyncCapabilities.java,v 1.4 2003/07/03 17:01:31 stefano_fornari Exp $
 *
 */
public final class SyncCapabilities
{
    private SyncType[] m_types;

    /**
     *
     * @param types array length must be greater than zero
     *
     * @throws java.lang.IllegalArgumentException
     *
     */
    public SyncCapabilities(final SyncType[] types)
    {
        if (types == null)
        {
            throw new NullPointerException(
                    "SyncType[] array parameter");
        }

        m_types = (SyncType[]) types.clone();

        if (m_types.length < 1)
        {
            throw new IllegalArgumentException(
                    "SyncType[] array parameter: length is < 1");
        }

        for (int i = 0; i < m_types.length; i++)
        {
            if (m_types[i] == null)
            {
                throw new NullPointerException(
                        "SyncType array has a null value at index "
                        + i);
            }
        }
    }

    /**
     *
     * @param eSyncCap must be non-null
     *
     */
    SyncCapabilities(final Element eSyncCap)
            throws RepresentationException
    {
        // todo : verify that eSyncCap is <SyncCap> - ?
        this(Util.extractSyncTypes(eSyncCap, true));
    }

    /**
     *
     * @return The return value is guaranteed to be non-null.
     *      Also, the array's elements are guaranteed to
     *      be non-null.
     *
     */
    public SyncType[] getSyncTypes()
    {
        return (SyncType[]) m_types.clone();
    }

    /**
     *
     * @return an XML representation of this object
     *
     */
    String toXML()
    {
        StringBuffer sbXML;
        sbXML = new StringBuffer();
        sbXML.append("<SyncCap>");
        for (int i = 0; i < m_types.length; i++)
        {
            sbXML.append(m_types[i].toXML());
        }
        sbXML.append("</SyncCap>\n");
        return sbXML.toString();
    }
}
