/*
 Copyright (c) 2001-2003 sync4j project
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.

 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.

 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */


package sync4j.framework.core;


/**
 *
 *  corresponds to &ltSyncType&gt tag in SyncML devinfo DTD
 *
 *
 *  @author Sean C. Sullivan
 *  @author Stefano Fornari @ Funambol
 *
 *
 *  @version $Id: SyncType.java,v 1.4 2003/07/19 16:28:27 stefano_fornari Exp $
 */
public final class SyncType {
    // --------------------------------------------------------------- Constants
    
    public static final SyncType TWO_WAY             = new SyncType(1);
    public static final SyncType SLOW                = new SyncType(2);
    public static final SyncType ONE_WAY_FROM_CLIENT = new SyncType(3);
    public static final SyncType REFRESH_FROM_CLIENT = new SyncType(4);
    public static final SyncType ONE_WAY_FROM_SERVER = new SyncType(5);
    public static final SyncType REFRESH_FROM_SERVER = new SyncType(6);
    public static final SyncType SERVER_ALERTED      = new SyncType(7);
    
    public static final SyncType[] ALL_SYNC_TYPES = new SyncType[] {
        TWO_WAY, SLOW, ONE_WAY_FROM_CLIENT, REFRESH_FROM_CLIENT,
        ONE_WAY_FROM_SERVER, REFRESH_FROM_SERVER, SERVER_ALERTED
    };
    
    private int type;

    private SyncType(final int type) {
        this.type = type;
    }
    
    public int getType() {
        return type;
    }

    /**
     *
     *  @return an XML representation of this object
     *
     */
    String toXML() {
        StringBuffer sbXML = new StringBuffer();
        sbXML.append("<SyncType>");
        sbXML.append(type);
        sbXML.append("</SyncType>\n");
        return sbXML.toString();
    }


    public static final SyncType getInstance(final int type) {
        if ((type < 0) || (type >= ALL_SYNC_TYPES.length)) {
            throw new IllegalArgumentException("unknown sync type: " + type);
        }
        
        return ALL_SYNC_TYPES[type-1];
        }
}
