/*
 Copyright (c) 2001-2003 sync4j project
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.

 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.

 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */

package sync4j.framework.core;

import sync4j.framework.core.xml.*;
import sync4j.framework.core.RepresentationException;

import java.util.Enumeration;
import java.util.Vector;

/**
 *
 *   utilities
 *
 *  @author Sean C. Sullivan
 *  @author Stefano Fornari @ Funambol
 *  @author david.buchmann at unifr.ch
 *
 *  @version $Id: Util.java,v 1.15 2003/12/27 21:33:29 stefano_fornari Exp $
 *
 */
public final class Util
{
    private static IXmlOperation adaptee;
    
    static {
        adaptee = new sync4j.framework.core.xml.nanoxml.XmlOperationImpl();
    }
    
    private Util() {    
    }
     
    public static Element toElement(
            final String strXMLFragment,
            final String strElementName)
        throws RepresentationException {
        try {
            return adaptee.toElement(strXMLFragment, strElementName);
        } catch (ParseException e) {
            throw new RepresentationException(e.getMessage(), e);
        }
    }

    public static Element extractElement(
        final Element eParent,
        final String strChildName,
        final boolean bElementIsRequired)
        throws RepresentationException {
        try {
            return adaptee.extractElement(eParent,
                                      strChildName,
                                      bElementIsRequired);
        } catch (ParseException e) {
            throw new RepresentationException(e.getMessage(), e);
        }
    }
    
    public static Element extractElement(
        final Element eParent,
        final String strChildName,
        final boolean bElementIsRequired,
                final Object ns)
        throws RepresentationException  {
        try {
            return adaptee.extractElement(eParent, strChildName, 
                    bElementIsRequired, ns);
        } catch(ParseException e) {
            throw new RepresentationException(e.getMessage(), e);
        }
    }
    
    public static String extractElementText(
            final Element eParent           ,
            final String  strChildName      ,
            final boolean bElementIsRequired,
            final Object  ns                )
        throws RepresentationException   {
        try {
            return adaptee.extractElementText(eParent, strChildName,
                    bElementIsRequired, ns);
        } catch(ParseException e) {
            throw new RepresentationException(e.getMessage(), e);
        }
    }

    public static String extractElementText(
                final Element eParent,
                final String strChildName,
                final boolean bElementIsRequired)
        throws RepresentationException  {
        try {
            return adaptee.extractElementText(eParent ,
                                      strChildName,
                                      bElementIsRequired);
        } catch(ParseException e) {
            throw new RepresentationException(e.getMessage(), e);
        }                         
    }

    public static Namespace getNamespace(String uri) {
        return adaptee.getNamespace(uri);
    }
    
    public static Element castToElement(Object obj) {
        return adaptee.castToElement(obj);
    }
    
    static DTDVersion extractDTDVersion(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        // todo : re-write this - ?
        return new DTDVersion(
                Util.extractElementText(
                        eParent,
                        "VerDTD",
                        bElementIsRequired));
    }

    static ProtocolVersion extractVerProto(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        // todo : re-write this - ?
        return new ProtocolVersion(
                Util.extractElementText(
                        eParent,
                        "VerProto",
                        bElementIsRequired));
    }

    static SyncSessionIdentifier extractSessionID(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        // todo : re-write this - ?
        return new SyncSessionIdentifier(
                Util.extractElementText(
                        eParent,
                        "SessionID",
                        bElementIsRequired));
    }

    static String extractLang(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        return Util.extractElementText(
                eParent,
                "Lang",
                bElementIsRequired);
    }

    static String extractMessageID(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        return Util.extractElementText(
                eParent,
                "MsgID",
                bElementIsRequired);
    }

    static SyncHeader extractSyncHeader(
            final Element eParent)
            throws RepresentationException
    {
        Element e = extractElement(
                eParent,
                "SyncHdr",
                true);
        if (e == null)
        {
            throw new RepresentationException("missing SyncHdr");
        }
        return new SyncHeader(e);
    }

    static SyncBody extractSyncBody(
            final Element eParent)
            throws RepresentationException
    {
        Element e = extractElement(
                eParent,
                "SyncBody",
                true);
        if (e == null)
        {
            throw new RepresentationException("missing SyncBody");
        }
        return new SyncBody(e);
    }

    static Target extractTarget(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Element e = extractElement(
                eParent,
                "Target",
                bElementIsRequired);
        if (e == null)
        {
            // todo : is this right?
            return null;
        }
        return new Target(e);
    }

    static Source extractSource(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Element e = extractElement(
                eParent,
                "Source",
                bElementIsRequired);
        if (e == null)
        {
            // todo : is this right?
            return null;
        }
        return new Source(e);
    }

    static Source[] extractSources(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Vector vSources = new Vector();
        for (Enumeration enum = eParent.getChildren(); enum.hasMoreElements();)
        {
            Element e = (Element)enum.nextElement();
            if (e.getName().equals("Source"))
            {
                vSources.addElement(new Source(e));
            }
        }
        if (vSources.size() < 1) // todo : should this be here???
        {
            // todo : throw exception
        }

        /*  
            Not compatible with j2me
            Source[] aSources = new Source[size];
            return (Source[]) vSources.toArray(aSources);
        */
        int size = vSources.size();
        Source[] aSources = new Source[size];
        for (int i=0; i<size; i++) {
            aSources[i] = (Source)vSources.elementAt(i);
        }
        return aSources;
    }


    static String extractLocName(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        String strText = extractElementText(
                eParent,
                "LocName",
                bElementIsRequired);
        return strText;
    }

    static String extractRespURI(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        return Util.extractURI(
                eParent,
                "RespURI",
                bElementIsRequired);
    }


    static boolean extractNoResults(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        return Util.extractBooleanResult(
                eParent,
                "NoResults",
                bElementIsRequired);
    }

    static boolean extractSharedMem(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        return Util.extractBooleanResult(
                eParent,
                "SharedMem",
                bElementIsRequired);
    }

    static boolean extractArchive(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        return Util.extractBooleanResult(
                eParent,
                "Archive",
                bElementIsRequired);
    }


    static boolean extractSftDel(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        return Util.extractBooleanResult(
                eParent,
                "SftDel",
                bElementIsRequired);
    }


    static boolean extractNoResp(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        return Util.extractBooleanResult(
                eParent,
                "NoResp",
                bElementIsRequired);
    }

    private static boolean extractBooleanResult(
            final Element eParent,
            final String strElementName,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Element e = extractElement(
                eParent,
                strElementName,
                bElementIsRequired);
        if (e == null)
        {
            return false;
        }
        return true;
    }

    static Credential extractCred(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Element eCred = Util.extractElement(
                eParent,
                "Cred",
                bElementIsRequired);
        if (eCred == null)
        {
            return null;
        }
        return new Credential(eCred);
    }

    static Meta extractMeta(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Element eMeta = Util.extractElement(
                eParent,
                "Meta",
                bElementIsRequired);
        if (eMeta == null)
        {
            return null;
        }
        return new Meta(eMeta);
    }


    static Data extractData(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Element eData = Util.extractElement(
                eParent,
                "Data",
                bElementIsRequired);
        if (eData == null)
        {
            return null;
        }
        return new Data(eData);
    }


    static AbstractCommand[] extractAbstractCommands(
        final Element eParent,
        final boolean bElementIsRequired)
        throws RepresentationException
    {
        Vector vCommands = new Vector();
        for (Enumeration enum = eParent.getChildren(); enum.hasMoreElements();)
        {
            Element e = (Element)enum.nextElement();
            final String strName = e.getName();
            if (strName.equals(AlertCommand.COMMAND_NAME))
            {
              vCommands.addElement(new AlertCommand(e));
            }
            else if (strName.equals(AddCommand.COMMAND_NAME))
            {
              vCommands.addElement(new AddCommand(e));
            }
            else if (strName.equals(AtomicCommand.COMMAND_NAME))
            {
              vCommands.addElement(new AtomicCommand(e));
            }
            else if (strName.equals(CopyCommand.COMMAND_NAME))
            {
              vCommands.addElement(new CopyCommand(e));
            }
            else if (strName.equals(DeleteCommand.COMMAND_NAME))
            {
              vCommands.addElement(new DeleteCommand(e));
            }
            else if (strName.equals(ExecCommand.COMMAND_NAME))
            {
              vCommands.addElement(new ExecCommand(e));
            }
            else if (strName.equals(GetCommand.COMMAND_NAME))
            {
              vCommands.addElement(new GetCommand(e));
            }
            else if (strName.equals(MapCommand.COMMAND_NAME))
            {
              vCommands.addElement(new MapCommand(e));
            }
            else if (strName.equals(PutCommand.COMMAND_NAME))
            {
              vCommands.addElement(new PutCommand(e));
            }
            else if (strName.equals(ReplaceCommand.COMMAND_NAME))
            {
              vCommands.addElement(new ReplaceCommand(e));
            }
            else if (strName.equals(SearchCommand.COMMAND_NAME))
            {
              vCommands.addElement(new SearchCommand(e));
            }
            else if (strName.equals(SequenceCommand.COMMAND_NAME))
            {
              vCommands.addElement(new SequenceCommand(e));
            }
            else if (strName.equals(SyncCommand.COMMAND_NAME))
            {
              vCommands.addElement(new SyncCommand(e));
            }
            else
            {
                // todo : throw exception here ?
            }
        }
        if (vCommands.size() < 1)
        {
            // todo : throw exception here - ?
        }
        /* Not compatible with j2me
        AbstractCommand[] aCommands = new AbstractCommand[vCommands.size()];
        return (AbstractCommand[]) vCommands.toArray( ((Object[]) aCommands) );
        */
        int size = vCommands.size();
        AbstractCommand[] aCommands = new AbstractCommand[size];
        for (int i=0; i<size; i++) {
            aCommands[i] = (AbstractCommand)vCommands.elementAt(i);
        }
        return aCommands;
    }

    // corresponds to the <Cmd> element in <Status>
    //
    // note: "The Cmd element type specifies the name of the
    //        SyncML command associated with the SyncML
    //        request. The value of the element type can
    //        also be "SyncHdr" when the CmdRef element type
    //        has a value of '0'"
    //
    static String extractCommandName(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        String strText = extractElementText(
                eParent,
                "Cmd",
                bElementIsRequired);
        return strText;
    }

    static AbstractCommand[] extractCommands(
        final Element eParent,
        final boolean bElementIsRequired)
        throws RepresentationException
    {
        Vector vCommands = new Vector();
        for (Enumeration enum = eParent.getChildren(); enum.hasMoreElements();)
        {
            Element e = (Element)enum.nextElement();
            final String strName = e.getName();
            if (strName.equals(AddCommand.COMMAND_NAME))
            {
              vCommands.addElement(new AddCommand(e));
            }
            else if (strName.equals(AlertCommand.COMMAND_NAME))
            {
              vCommands.addElement(new AlertCommand(e));
            }
            else if (strName.equals(AtomicCommand.COMMAND_NAME))
            {
              vCommands.addElement(new AtomicCommand(e));
            }
            else if (strName.equals(CopyCommand.COMMAND_NAME))
            {
              vCommands.addElement(new CopyCommand(e));
            }
            else if (strName.equals(DeleteCommand.COMMAND_NAME))
            {
              vCommands.addElement(new DeleteCommand(e));
            }
            else if (strName.equals(ExecCommand.COMMAND_NAME))
            {
              vCommands.addElement(new ExecCommand(e));
            }
            else if (strName.equals(GetCommand.COMMAND_NAME))
            {
              vCommands.addElement(new GetCommand(e));
            }
            else if (strName.equals(MapCommand.COMMAND_NAME))
            {
              vCommands.addElement(new MapCommand(e));
            }
            else if (strName.equals(PutCommand.COMMAND_NAME))
            {
              vCommands.addElement(new PutCommand(e));
            }
            else if (strName.equals(ReplaceCommand.COMMAND_NAME))
            {
              vCommands.addElement(new ReplaceCommand(e));
            }
            else if (strName.equals(ResultsCommand.COMMAND_NAME))
            {
              vCommands.addElement(new ResultsCommand(e));
            }
            else if (strName.equals(SearchCommand.COMMAND_NAME))
            {
              vCommands.addElement(new SearchCommand(e));
            }
            else if (strName.equals(SequenceCommand.COMMAND_NAME))
            {
              vCommands.addElement(new SequenceCommand(e));
            }
            else if (strName.equals(StatusCommand.COMMAND_NAME))
            {
              vCommands.addElement(new StatusCommand(e));
            }
            else if (strName.equals(SyncCommand.COMMAND_NAME))
            {
              vCommands.addElement(new SyncCommand(e));
            }
            else if (strName.equals("Final"))
            {
              // ignore it
            }
            else
            {
                throw new RepresentationException(
                    "unknown command: <"
                    + strName
                    + ">");
            }
        }
        if (vCommands.size() < 1)
        {
            // todo : throw exception here - ?
        }
        /* Not compatible with j2me
        AbstractCommand[] aCommands = new AbstractCommand[vCommands.size()];
        return (AbstractCommand[]) vCommands.toArray( ((Object[]) aCommands) );
        */
        int size = vCommands.size();
        AbstractCommand[] aCommands = new AbstractCommand[size];
        for (int i=0; i<size; i++) {
            aCommands[i] = (AbstractCommand)vCommands.elementAt(i);
        }
        return aCommands;

    }

    static boolean extractFinal(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Element eFinal = Util.extractElement(
                eParent,
                "Final",
                bElementIsRequired);
        if (eFinal == null)
        {
            return false;
        }
        return true;
    }


    static String extractFormat(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        return Util.extractElementText(
                eParent,
                "Format",
                bElementIsRequired);
    }

    static String extractType(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        return Util.extractElementText(
                eParent,
                "Type",
                bElementIsRequired,
                Constants.NAMESPACE_METINF);
    }

    static CommandIdentifier extractCommandId(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        // todo : doublecheck this method's behavior
        String strText = Util.extractElementText(
                eParent,
                "CmdID",
                bElementIsRequired);
        if ((bElementIsRequired == false) && (strText == null))
        {
            return null;
        }
        return new CommandIdentifier(strText);
    }

    static int extractAlertCode(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Element eData = Util.extractElement(
                eParent,
                "Data",
                bElementIsRequired);
        return Integer.parseInt(eData.getText());
    }

    static Item extractItem(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Element eItem = Util.extractElement(
                eParent,
                "Item",
                bElementIsRequired);
        return new Item(eItem);
    }

    static Item[] extractItems(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Vector vItems = new Vector();
        for (Enumeration enum = eParent.getChildren(); enum.hasMoreElements();)
        {
            Element e = (Element)enum.nextElement();
            if (e.getName().equals("Item"))
            {
                vItems.addElement(new Item(e));
            }
        }
        if (vItems.size() < 1) // todo : should this be here???
        {
            // todo : throw exception
        }

        int size = vItems.size();
        Item[] aItems = new Item[size];
        for (int i=0; i<size; i++) {
            aItems[i] = (Item)vItems.elementAt(i);
        }
        return aItems;
    
    }

    static MapItem[] extractMapItems(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Vector vMapItems = new Vector();
        for (Enumeration enum = eParent.getChildren(); enum.hasMoreElements();)
        {
            Element e = (Element)enum.nextElement();
            if (e.getName().equals("MapItem"))
            {
                vMapItems.addElement(new MapItem(e));
            }
        }
        if (vMapItems.size() < 1) // todo : should this be here???
        {
            // todo : throw exception
        }
        /* Not compatible with j2me
        MapItem[] aMapItems = new MapItem[vMapItems.size()];
        return (MapItem[]) vMapItems.toArray(aMapItems);
        */
        int size = vMapItems.size();
        MapItem[] aMapItems = new MapItem[size];
        for (int i=0; i<size; i++) {
            aMapItems[i] = (MapItem)vMapItems.elementAt(i);
        }
        return aMapItems;
    }

    static String extractLocURI(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        return extractURI(
                eParent,
                "LocURI",
                bElementIsRequired);
    }

    private static String extractURI(
            final Element eParent,
            final String strChildName,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Element e = extractElement(
                eParent,
                strChildName,
                bElementIsRequired);
        if (e == null)
        {
            if (bElementIsRequired) {
                throw new RepresentationException(
                    "Missing required element " + strChildName);
            } else {
                return null;
            }
        }
        String u = extractElementText(
                eParent,
                strChildName,
                bElementIsRequired);
        return u;
    }

    static AuthenticationChallenge extractChal(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Element eChal = Util.extractElement(
                eParent,
                "Chal",
                bElementIsRequired);
        if (eChal == null)
        {
            return null;
        }
        return new AuthenticationChallenge(eChal);
    }

    static TargetRef extractTargetRef(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Element eTargetRef = Util.extractElement(
                eParent,
                "TargetRef",
                bElementIsRequired);
        if (eTargetRef == null)
        {
            return null;
        }
        return new TargetRef(eTargetRef);
    }

    static SourceRef extractSourceRef(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Element eSourceRef = Util.extractElement(
                eParent,
                "SourceRef",
                bElementIsRequired);
        if (eSourceRef == null)
        {
            return null;
        }
        return new SourceRef(eSourceRef);
    }

    static SourceRef[] extractSourceRefs(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Vector vSourceRefs = new Vector();
        for (Enumeration enum = eParent.getChildren(); enum.hasMoreElements();)
        {
            Element e = (Element)enum.nextElement();
            if (e.getName().equals("SourceRef"))
            {
                vSourceRefs.addElement(new SourceRef(e));
            }
        }
        // todo : should this be here???
        if (bElementIsRequired
                && (vSourceRefs.size() < 1))
        {
            // todo : throw exception
        }
        /*  
            Not compatible with j2me
            SourceRef[] aSourceRefs = new SourceRef[vSourceRefs.size()];
            return (SourceRef[]) vSourceRefs.toArray(aSourceRefs);
        */
        int size = vSourceRefs.size();
        SourceRef[] aSourceRefs = new SourceRef[size];
        for (int i=0; i<size; i++) {
            aSourceRefs[i] = (SourceRef)vSourceRefs.elementAt(i);
        }
        return aSourceRefs;

    }

    static TargetRef[] extractTargetRefs(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Vector vTargetRefs = new Vector();
        for (Enumeration enum = eParent.getChildren(); enum.hasMoreElements();)
        {
            Element e = (Element)enum.nextElement();
            if (e.getName().equals("TargetRef"))
            {
                vTargetRefs.addElement(new TargetRef(e));
            }
        }
        // todo : should this be here???
        if (bElementIsRequired
                && (vTargetRefs.size() < 1))
        {
            // todo : throw exception
        }
        /* not compatible with j2me
            TargetRef[] aTargetRefs = new TargetRef[vTargetRefs.size()];
            return (TargetRef[]) vTargetRefs.toArray(aTargetRefs);
        */
        int size = vTargetRefs.size();
        TargetRef[] aTargetRefs = new TargetRef[size];
        for (int i=0; i < size; i++) {
            aTargetRefs[i] = (TargetRef)vTargetRefs.elementAt(i);
        }
        return aTargetRefs;
        
    }

    static String extractMessageRef(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        String strText = extractElementText(
                eParent,
                "MsgRef",
                bElementIsRequired);
        return strText;
    }

    static String extractCommandRef(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        String strText = extractElementText(
                eParent,
                "CmdRef",
                bElementIsRequired);
        return strText;
    }

    static String extractManufacturer(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        String strText = extractElementText(
                eParent,
                "Man",
                bElementIsRequired);
        return strText;
    }

    static String extractModelName(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        String strText = extractElementText(
                eParent,
                "Mod",
                bElementIsRequired);
        return strText;
    }

    static String extractOEM(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        String strText = extractElementText(
                eParent,
                "OEM",
                bElementIsRequired);
        return strText;
    }

    static String extractFirmwareVersion(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        String strText = extractElementText(
                eParent,
                "FwV",
                bElementIsRequired);
        return strText;
    }

    static String extractSoftwareVersion(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        String strText = extractElementText(
                eParent,
                "SwV",
                bElementIsRequired);
        return strText;
    }

    static String extractHardwareVersion(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        String strText = extractElementText(
                eParent,
                "HwV",
                bElementIsRequired);
        return strText;
    }

    static String extractDevID(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        String strText = extractElementText(
                eParent,
                "DevID",
                bElementIsRequired);
        return strText;
    }


    static String extractDevTyp(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        String strText = extractElementText(
                eParent,
                "DevTyp",
                bElementIsRequired);
        return strText;
    }

    static ContentTypeInfo[] extractTxs(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {

        Vector vTxs = new Vector();
        for (Enumeration enum = eParent.getChildren(); enum.hasMoreElements();)
        {
            Element e = (Element)enum.nextElement();
            final String strName = e.getName();
            if (strName.equals("Tx"))
            {
                vTxs.addElement(new ContentTypeInfo(e));
            }
        }

        if ((bElementIsRequired)
                && (vTxs.size() == 0))
        {
            throw new RepresentationException("todo  : exception in Util.extractTxs");
        }

        /* not compatible with j2me
            ContentTypeInfo[] aTxs = new ContentTypeInfo[vTxs.size()];
            return (ContentTypeInfo[]) vTxs.toArray((Object[]) aTxs);
        */
        int size = vTxs.size();
        ContentTypeInfo[] aTxs = new ContentTypeInfo[size];
        for (int i=0; i < size; i++) {
            aTxs[i] = (ContentTypeInfo)vTxs.elementAt(i);
        }
        return aTxs;

    }

    static ContentTypeInfo extractTxPref(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Element eTxPref = extractElement(
                eParent,
                "Tx-Pref",
                bElementIsRequired);
        return new ContentTypeInfo(eTxPref);
    }

    static ContentTypeInfo[] extractRxs(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Vector vRxs = new Vector();
        for (Enumeration enum = eParent.getChildren(); enum.hasMoreElements();)
        {
            Element e = (Element)enum.nextElement();
            final String strName = e.getName();
            if (strName.equals("Rx"))
            {
                vRxs.addElement(new ContentTypeInfo(e));
            }
        }

        if ((bElementIsRequired)
                && (vRxs.size() == 0))
        {
            throw new RepresentationException("todo  : exception in Util.extractRxs");
        }

        /* not compatible with j2me
            ContentTypeInfo[] aRxs = new ContentTypeInfo[vRxs.size()];
            return (ContentTypeInfo[]) vRxs.toArray((Object[]) aRxs);
        */
        int size = vRxs.size();
        ContentTypeInfo[] aRxs = new ContentTypeInfo[size];
        for (int i=0; i < size; i++) {
            aRxs[i] = (ContentTypeInfo)vRxs.elementAt(i);
        }
        return aRxs;
    }

    static ContentTypeInfo extractRxPref(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Element eRxPref = extractElement(
                eParent,
                "Rx-Pref",
                bElementIsRequired);
        return new ContentTypeInfo(eRxPref);
    }

    static DataStoreMemoryInfo extractDSMem(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Element eDSMem = extractElement(
                eParent,
                "DSMem",
                bElementIsRequired);
        
        //
        // If the element is not required and not in the eParent subtree, 
        // extractElement returns null
        //
        return (eDSMem == null) ? null : new DataStoreMemoryInfo(eDSMem);
    }

    static SyncCapabilities extractSyncCap(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Element eSyncCap = extractElement(
                eParent,
                "SyncCap",
                bElementIsRequired);
        return new SyncCapabilities(eSyncCap);
    }

    static SyncAnchor extractAnchor(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Element eAnchor = extractElement(
                eParent,
                "Anchor",
                bElementIsRequired,
                Constants.NAMESPACE_METINF);
        if (eAnchor == null)
        {
            return null;
        }
        return new SyncAnchor(eAnchor);
    }

    static String extractLast(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        String strText = extractElementText(
                eParent,
                "Last",
                bElementIsRequired);
        if (strText == null)
        {
            return null;
        }
        return strText;
    }

    static String extractNext(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        String strText = extractElementText(
                eParent,
                "Next",
                bElementIsRequired);
        if (strText == null)
        {
            return null;
        }
        return strText;
    }

    static long extractMaxGUIDSize(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        return extract_long(eParent,
                "MaxGUIDSize",
                bElementIsRequired,
                -1);
    }

    static long extractSize(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        return extract_long(eParent,
                "Size",
                bElementIsRequired,
                -1);
    }

    static long extractMaxMsgSize(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        return extract_long(eParent,
                "MaxMsgSize",
                bElementIsRequired,
                -1);
    }

    static long extractMaxMem(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        return extract_long(eParent,
                "MaxMem",
                bElementIsRequired,
                -1);
    }

    static long extractMaxID(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        return extract_long(eParent,
                "MaxID",
                bElementIsRequired,
                -1);
    }

    private static long extract_long(
            final Element eParent,
            final String strElementName,
            final boolean bElementIsRequired,
            final long lDefaultValue)
            throws RepresentationException
    {
        long lResult = 0L;

        try
        {
            String strText = extractElementText(
                    eParent,
                    strElementName,
                    bElementIsRequired);
            lResult = (strText == null) 
                        ? lDefaultValue 
                        : Long.parseLong(strText);
        }
        catch (Exception ex)
        {
            // todo : change exception handling?
            throw new RepresentationException("todo");
        }

        return lResult;
    }


    static String extractDisplayName(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        String strText = extractElementText(
                eParent,
                "DisplayName",
                bElementIsRequired);
        return strText;
    }

    static String extractXNam(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        String strText = extractElementText(
                eParent,
                "XNam",
                bElementIsRequired);
        return strText;
    }

    static String[] extractXVals(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Vector vXVals = new Vector();
        for (Enumeration enum = eParent.getChildren(); enum.hasMoreElements();)
        {
            Element e = (Element)enum.nextElement();
            final String strName = e.getName();
            if (strName.equals("XVal"))
            {
                String strText = e.getText();
                vXVals.addElement(strText);
            }
        }

        if ((bElementIsRequired)
                && (vXVals.size() == 0))
        {
            throw new RepresentationException("todo  : msg here");
        }

        /* not compatible with j2me
            String[] aXVals = new String[vXVals.size()];
            return (String[]) vXVals.toArray((Object[]) aXVals);
        */
        int size = vXVals.size();
        String[] aXVals = new String[size];
        for (int i=0; i < size; i++) {
            aXVals[i] = (String)vXVals.elementAt(i);
        }
        return aXVals;
    }

    static DataStore[] extractDataStores(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Vector vDataStores = new Vector();
        for (Enumeration enum = eParent.getChildren(); enum.hasMoreElements();)
        {
            Element e = (Element)enum.nextElement();
            final String strName = e.getName();
            if (strName.equals("DataStore"))
            {
                vDataStores.addElement(new DataStore(e));
            }
        }

        if ((bElementIsRequired)
                && (vDataStores.size() == 0))
        {
            throw new RepresentationException("todo : msg here");
        }

        /* not compatible with j2me
            DataStore[] aDataStores = new DataStore[vDataStores.size()];
            return (DataStore[]) vDataStores.toArray((Object[]) aDataStores);
        */
        int size = vDataStores.size();
        DataStore[] aDataStores = new DataStore[size];
        for (int i=0; i < size; i++) {
            aDataStores[i] = (DataStore)vDataStores.elementAt(i);
        }
        return aDataStores;
    }

    static ExperimentalMetaInfo[] extractEMIs(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Vector vEMIs = new Vector();
        for (Enumeration enum = eParent.getChildren(); enum.hasMoreElements();)        {
            Element e = (Element)enum.nextElement();
            final String strName = e.getName();
            if (strName.equals("EMI"))
            {
                vEMIs.addElement(new ExperimentalMetaInfo(e));
            }
        }

        if ((bElementIsRequired)
                && (vEMIs.size() == 0))
        {
            throw new RepresentationException("<EMI> element is missing");
        }

        /* not compatible with j2me
            ExperimentalMetaInfo[] aEMIs = new ExperimentalMetaInfo[vEMIs.size()];
            return (ExperimentalMetaInfo[]) vEMIs.toArray((Object[]) aEMIs);
        */
        int size = vEMIs.size();
        ExperimentalMetaInfo[] aEMIs = new ExperimentalMetaInfo[size];
        for (int i=0; i < size; i++) {
            aEMIs[i] = (ExperimentalMetaInfo)vEMIs.elementAt(i);
        }
        return aEMIs;
    }

    static ContentTypeCapability[] extractContentTypeCapabilities(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        // todo : real code here
        ContentTypeProperty[] props = new ContentTypeProperty[1];
        props[0] = new ContentTypeProperty(
                null,
                null,
                null,
                null);
        ContentTypeCapabilityItem[] actci = new ContentTypeCapabilityItem[1];
        actci[0] = new ContentTypeCapabilityItem(
                "text/plain",
                props);
        ContentTypeCapability[] result = new ContentTypeCapability[1];
        result[0] = new ContentTypeCapability(actci);
        return result;
    }

    static SyncType[] extractSyncTypes(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Vector vSyncTypes = new Vector();
        for (Enumeration enum = eParent.getChildren(); enum.hasMoreElements();)
        {
            Element e = (Element)enum.nextElement();
            final String strName = e.getName();
            if (strName.equals("SyncType"))
            {
                try
                {
                    vSyncTypes.addElement(SyncType.getInstance(
                                            Integer.parseInt(e.getText())));
                }
                catch (Exception ex)
                {
                    throw new RepresentationException(
                            "todo : message here");
                }
            }
        }

        /* not compatible with j2me
        SyncType[] aSyncTypes = new SyncType[vSyncTypes.size()];
        return (SyncType[]) vSyncTypes.toArray((Object[]) aSyncTypes);
        */
        int size = vSyncTypes.size();
        SyncType[] aSyncTypes = new SyncType[size];
        for (int i=0; i < size; i++) {
            aSyncTypes[i] = (SyncType)vSyncTypes.elementAt(i);
        }
        return aSyncTypes;
    }

    static Extension[] extractExtensions(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Vector vExtensions = new Vector();
        for (Enumeration enum = eParent.getChildren(); enum.hasMoreElements();)
        {
            Element e = (Element)enum.nextElement();
            final String strName = e.getName();
            if (strName.equals("Ext"))
            {
                vExtensions.addElement(new Extension(e));
            }
        }
       
        int size = vExtensions.size();
        Extension[] aExtensions = new Extension[size];
        for (int i=0; i < size; i++) {
            aExtensions[i] = (Extension)vExtensions.elementAt(i);
        }
        return aExtensions;
    }

    static String extractCTType(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        String strText = extractElementText(
                eParent,
                "CTType",
                bElementIsRequired);
        return strText;
    }

    static String extractVerCT(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        String strText = extractElementText(
                eParent,
                "VerCT",
                bElementIsRequired);
        return strText;
    }

    static String extractMark(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        String strText = extractElementText(
                eParent,
                "Mark",
                bElementIsRequired);
        return strText;
    }

    static String extractVersion(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        String strText = extractElementText(
                eParent,
                "Version",
                bElementIsRequired);
        return strText;
    }


    static MemoryInfo extractMem(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        Element eMem = extractElement(
                eParent,
                "Mem",
                bElementIsRequired);
        if (eMem == null)
        {
            return null;
        }
        return new MemoryInfo(eMem);
    }

    static NextNonce extractNextNonce(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {

        Element eNextNonce = extractElement(
                eParent,
                "NextNonce",
                bElementIsRequired);
        if ((eNextNonce == null)
                && (bElementIsRequired == false))
        {
            return null;
        }
        String strText = eNextNonce.getText();
        // todo : throw exception if strText is null?
        // todo : rethink 2nd parameter:
        return new NextNonce(strText, true);
    }

    static ContentTypeCapabilityItem[] extractContentTypeCapabilityItems(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        // todo : code here
        return new ContentTypeCapabilityItem[1];
    }

    static long extractFreeMem(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        return extract_long(eParent,
                "FreeMem",
                bElementIsRequired,
                -1);
    }

    static long extractFreeID(
            final Element eParent,
            final boolean bElementIsRequired)
            throws RepresentationException
    {
        return extract_long(eParent,
                "FreeID",
                bElementIsRequired,
                -1);
    }

    static void verifyLengthGreaterThanZero(final String s)
    {
        if (s.length() < 1)
        {
            throw new IllegalArgumentException(
                    "String length is less than 1");
        }
    }

    static void verifyNonNull(final Object obj)
    {
        if (obj == null)
        {
            throw new NullPointerException(
                    obj.getClass().toString()
                    + " parameter is null");
        }
    }
    
    /** convert a xml element and all its children to string and removes the
     *  surrounding tag
     * 
     *  @param e the element to convert
     *
     *  @return the element content as String
     *
     */
    public static String contentAsString(final Element e) {
        String s = toString(e);
        s=s.substring(s.indexOf('>')+1); //remove leading tag
        int p = s.lastIndexOf('<');
        
        return (p < 0) ? s : s.substring(0, p); //remove end tag
    }
    
    /** convert a xml element and all its children to string.
     *
     * @param skipLeadingWhitespace how spaces and special charatcter should be treated
     *
     */
    public static String toString(final Element e, boolean skipLeadingWhitespace) {
        if (e == null) {
            throw new NullPointerException("XML element is null");
        }

        return adaptee.toString(e);
    }

    public static String toString(final Element e) {
        return toString(e, true);
    }
    
    /**
     * Determines if a string is empty. A string is empty when null or is trimmed
     * value length is 0.
     *
     * @param s the string to be checked
     *
     * @return true if the string is empty, false otherwise
     */
    static public boolean isEmpty(String s) {
        return ((s == null) || (s.trim().length() == 0));
    }

}
