/*
 *  Copyright (c) 2001-2002 sync4j project
 *  All rights reserved.
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  1. Redistributions of source code must retain the above copyright
 *  notice, this list of conditions, and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions, and the disclaimer that follows
 *  these conditions in the documentation and/or other materials
 *  provided with the distribution.
 *  3. The name "sync4j" must not be used to endorse or promote products
 *  derived from this software without prior written permission.
 *  4. Products derived from this software may not be called "sync4j", nor
 *  may "sync4j" appear in their name, without prior written permission.
 *  In addition, we request (but do not require) that you include in the
 *  end-user documentation provided with the redistribution and/or in the
 *  software itself an acknowledgement equivalent to the following:
 *  "This product includes software developed by the
 *  sync4j project."
 *  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 *  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 *  OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *  DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 *  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 *  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 *  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 *  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 *  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE.
 */
package sync4j.framework.core.xml.nanoxml;

import nanoxml.kXMLElement;

import java.util.Enumeration;
import java.util.Vector;

/**
 * This class adapts to the class <code>kXMLElement</code> in the NanoXML DOM
 * API.
 *
 * @author    <a href="mailto:sso@users.sourceforge.net">Simon So</a>
 * @version   $Id: ElementImpl.java,v 1.5 2003/12/15 16:55:09 luigiafassina Exp $
 * @since     SyncML 1.1
 * @see       nanoxml.kXMLElement
 */
public class ElementImpl implements sync4j.framework.core.xml.Element {
    private kXMLElement element;


    /**
     * Adapts, or "wraps" the DOM API-specific Element object.
     *
     * @param e  Description of the Parameter
     */
    public ElementImpl(Object e) {
        element = (kXMLElement) e;
    }


    /**
     * Gets the element attribute of the ElementImpl object
     *
     * @return   The element value
     */
    public kXMLElement getElement() {
        return element;
    }


    /**
     * Gets the name attribute of the ElementImpl object
     *
     * @return   The name value
     */
    public String getName() {
        return element.getTagName();
    }


    /**
     * Gets the text attribute of the ElementImpl object
     *
     * @return   The text value
     */
    public String getText() {
        return element.getContents();
    }


    /**
     * @return   the parent of this instance.
     */
    public sync4j.framework.core.xml.Element getParent() {
        return new ElementImpl(element.getParent());
    }


    /**
     * @return   an enumeration of children
     */
    public Enumeration getChildren() {
        Vector ret = new Vector();
        
        for (Enumeration enum = element.getChildren().elements(); enum.hasMoreElements(); ) {
            kXMLElement e = (kXMLElement) enum.nextElement();
            ret.addElement(new ElementImpl(e));
        }
        
        return ret.elements();
    }


    /**
     * @param name  Description of the Parameter
     * @return      The children value
     * @see         <a href="http://www.jdom.org/docs/apidocs/org/jdom/Element.html#getChildren(java.lang.String)">
     *      here</a>
     */
    public Enumeration getChildren(String name) {
        Vector children = element.getChildren();
        Vector childrenWithMatchingName = new Vector();
        for (Enumeration enum = children.elements(); enum.hasMoreElements(); ) {
            kXMLElement e = (kXMLElement) enum.nextElement();
            if (e.getTagName().equals(name)) {
                childrenWithMatchingName.addElement(new ElementImpl(e));
            }
        }

        return childrenWithMatchingName.elements();
    }


    /**
     * Gets the text of child called this name.
     *
     * @param name  Description of the Parameter
     * @return      The childText value
     * @see         <a href="http://www.jdom.org/docs/apidocs/org/jdom/Element.html#getChildText(java.lang.String)">
     *      here</a>
     */
    public String getChildText(String name) {
        String content = null;
        Enumeration enum = getChildren(name);
        if (enum.hasMoreElements()) {
            content = ((kXMLElement) enum.nextElement()).getContents();
            if (content == null) {
                content = "";
            }
        } else {
            content = null;
        }

        return content;
    }


    /**
     * Returns the first occurrence in its children set.
     *
     * @param name       Description of the Parameter
     * @param namespace  Description of the Parameter
     * @return           The child value
     * @see              <a href="http://www.jdom.org/docs/apidocs/org/jdom/Element.html#getChild(java.lang.String)">
     *      here</a>
     */
    public ElementImpl getChild(String name, Object namespace) {
        Enumeration enum = getChildren(name);
        return (enum.hasMoreElements()) ? (ElementImpl) enum.nextElement() : null;
    }
}

