/*
 *  $Id: AccessType.java,v 1.5 2003/12/23 12:50:07 luigiafassina Exp $
 *  Copyright (c) 2001-2002 sync4j project
 *  All rights reserved.
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *  1. Redistributions of source code must retain the above copyright
 *  notice, this list of conditions, and the following disclaimer.
 *  2. Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions, and the disclaimer that follows
 *  these conditions in the documentation and/or other materials
 *  provided with the distribution.
 *  3. The name "sync4j" must not be used to endorse or promote products
 *  derived from this software without prior written permission.
 *  4. Products derived from this software may not be called "sync4j", nor
 *  may "sync4j" appear in their name, without prior written permission.
 *  In addition, we request (but do not require) that you include in the
 *  end-user documentation provided with the redistribution and/or in the
 *  software itself an acknowledgement equivalent to the following:
 *  "This product includes software developed by the
 *  sync4j project."
 *  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 *  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 *  OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 *  DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 *  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 *  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 *  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 *  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 *  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 *  SUCH DAMAGE.
 */
package sync4j.framework.dm;

import sync4j.framework.core.RepresentationException;
import sync4j.framework.core.xml.Element;
import sync4j.framework.core.Util;

import java.util.Enumeration;
import java.util.Vector;

/**
 * This class corresponds to &ltAccessType&gt element of the SyncML DM
 * Description Framework DTD. Content model: (Add?, Copy?, Delete?, Exec?,
 * Get?, Replace?)>
 *
 * @author    <a href="mailto:sso@users.sourceforge.net">Simon So</a>
 * @since     SyncML 1.1
 */
public final class AccessType extends BaseElement {
    /**
     * Description of the Field
     */
    public final static String ADD = "Add";
    /**
     * Description of the Field
     */
    public final static String COPY = "Copy";
    /**
     * Description of the Field
     */
    public final static String DELETE = "Delete";
    /**
     * Description of the Field
     */
    public final static String EXEC = "Exec";
    /**
     * Description of the Field
     */
    public final static String GET = "Get";
    /**
     * Description of the Field
     */
    public final static String REPLACE = "Replace";

    private String[] m_accessTypes;


    /**
     * Constructs an instance of AccessType
     *
     * @param s                             a string array of access type, as
     *      defined in DM DTD
     * @exception IllegalArgumentException  Description of the Exception
     * @exception NullPointerException      Description of the Exception
     * @throws IllegalArgumentException
     */
    public AccessType(String[] s)
         throws IllegalArgumentException, NullPointerException {
        if (s == null) {
            throw new NullPointerException(
                "<AccessType> must have contents");
        }

        // 7.4.3.1
        for (int i = 0; i < s.length; i++) {
            if (!(ADD.equals(s[i]) || COPY.equals(s[i])
                 || DELETE.equals(s[i]) || EXEC.equals(s[i])
                 || GET.equals(s[i]) || REPLACE.equals(s[i]))) {
                throw new IllegalArgumentException("Illegal value: " + s[i]);
            }
        }
        m_accessTypes = s;
    }


    /**
     * Extracts an array of access types from the JDOM element.
     *
     * @param eParent                  the parent of the node &ltAccessType&gt
     * @return                         an instance of <code>AccessType</code>
     * @throws RepresentationException  if &ltAccessType&gt cannot be found.
     */
    public static AccessType extractFrom(Element eParent)
         throws RepresentationException {
        // will throw exception if ate is null
        Element ate = Util.extractElement(eParent, "AccessType", true);

        Vector v = new Vector();
        for (Enumeration enum = ate.getChildren(); enum.hasMoreElements(); ) {
            Element e = Util.castToElement(enum.nextElement());
            v.addElement(e.getName());
        }

        try {
            int size = v.size();
            String[] aAccessTypes = new String[size];
            for (int i = 0; i < size; i++) {
                aAccessTypes[i] = (String) v.elementAt(i);
            }
            return new AccessType(aAccessTypes);
        } catch (Exception e) {
            throw new RepresentationException(e.getMessage());
        }
    }


    /**
     * Returns an XML string.
     *
     * @return   Description of the Return Value
     */
    public String toXML() {
        StringBuffer body = new StringBuffer();

        body.append("<AccessType>");
        for (int i = 0; i < m_accessTypes.length; i++) {
            body.append("<").append(m_accessTypes[i]).append("/>\n");
        }
        body.append("</AccessType>\n");

        return body.toString();
    }
}

