/*
 
 $Id: DFProperties.java,v 1.4 2003/12/23 12:50:07 luigiafassina Exp $
 
 Copyright (c) 2001-2002 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.
 
 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:
 
     "This product includes software developed by the
      sync4j project."
 
 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.
 
 */

package sync4j.framework.dm;

import sync4j.framework.core.*;

import sync4j.framework.core.xml.Element;

/**
 * This class corresponds to  &ltDFProperties&gt element of the
 * SyncML DM Description Framework DTD.
 *
 * Content model: (AccessType, DefaultValue?, Description?, DFFormat,
 *			Occurrence?, Scope?, DFTitle?, DFType?)
 *
 * @author  <a href="mailto:sso@users.sourceforge.net">Simon So</a>
 * @since   SyncML 1.1
 */
public final class DFProperties extends BaseElement
{
    private final AccessType m_accessTypes;
    
    private final String m_defaultValue;
    
    private final String m_description;
    
    private final Format m_dfFormat;
    
    private final Occurrence m_occurrence;
    
    private final Scope m_scope;
    
    private final String m_dfTitle;
    
    /**
     * <!ELEMENT DFType (MIME+)>
     */
    private final Type m_dfType;
    
    public Type getDFType()
    {
	return m_dfType;
    }
    
    /**
     * Constructs a Device Management Description Framework Properties
     * object.
     *
     * @param accessType	the accessType.  MUST have.
     * @param defaultValue
     * @param description
     * @param dfFormat
     * @param occurrence
     * @param scope
     * @param dfTitle
     * @param dfType
     */
    public DFProperties(final AccessType accessType,
			final String defaultValue,
			final String description,
			final Format dfFormat,
			final Occurrence occurrence,
			final Scope scope,
			final String dfTitle,
			final Type dfType)
    {
	if (accessType == null)
	{
	    throw new NullPointerException("AccessType of DFProperties is null");
	}
	
	if (dfFormat == null)
	{
	    throw new NullPointerException("DFFormat of DFProperties");
	}
	
	m_accessTypes = accessType;
	m_defaultValue = defaultValue;
	m_description = description;
	m_dfFormat = dfFormat;
	m_occurrence = occurrence;
	m_scope = scope;
	m_dfTitle = dfTitle;
	m_dfType = dfType;
    }
    
    /**
     * Constructs from a JDOM element.
     *
     * @param e	a JDOM parent that has &ltDFProperties&gt.
     */
    public DFProperties(final Element e) throws RepresentationException
    {
	this(AccessType.extractFrom(e),
	    Util.extractElementText(e, "DefaultValue", false),
	    Util.extractElementText(e, "Description", false),
	    Format.extractFrom(e, "DFFormat"),
	    Occurrence.extractFrom(e),
	    Scope.extractFrom(e),
	    Util.extractElementText(e, "DFTitle", false),
	    Type.extractFrom(e, "DFType"));
	}
    
    /**
     * Returns an XML representation of the tag.  Uses string literals
     * so that the code will always look from the string pool instead
     * of dynamically creating the tag by reflection and wasting resources.
     *
     * @return	an XML representation of the tag.
     */
    public String toXML()
    {
	StringBuffer body = new StringBuffer();
	
	body.append(m_accessTypes.toXML());
	
	body.append("<DFProperties>");
	
	if (m_defaultValue != null)
	{
	    body.append("<DefaultValue>")
	    .append(m_defaultValue)
	    .append("</DefaultValue>\n");
	}
	
	if (m_description != null)
	{
	    body.append("<Description>")
	    .append(m_description)
	    .append("</Description>\n");
	}
	
	body.append(m_dfFormat.toXML());
	
	body.append(m_occurrence.toXML());
	
	body.append(m_scope.toXML());
	
	if (m_dfTitle != null)
	{
	    body.append("<DFTitle>").append(m_dfTitle).append("</DFTitle>\n");
	}
	
	/**
	 * <!ELEMENT DFType (MIME+)>
	 * MUST for leaf objects; May for interior objects.
	 * todo: check for correctness
	 */
	if (m_dfType != null)
	{
	    body.append(m_dfType.toXML());
	}
	
	body.append("</DFProperties>\n");
	
	return body.toString();
    }
    
    /**
     *	Extracts a DFProperties object from a JDOM element.
     *
     *	@param eParent	the element parent
     *	@return	an instance of DFProperties
     *	@see	Node#Node(Element)
     */
    static DFProperties extractFrom(Element eParent)
	    throws RepresentationException
    {
	// will throw exception if e is null
	Element e = Util.extractElement(eParent,
					    "DFProperties",
					    true);
	return new DFProperties(e);
    }
}
