/*
 
 $Id: RTProperties.java,v 1.4 2003/12/23 12:50:07 luigiafassina Exp $
 
 Copyright (c) 2001-2002 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.
 
 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:
 
     "This product includes software developed by the
      sync4j project."
 
 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.
 
 */

package sync4j.framework.dm;

import sync4j.framework.core.*;

import sync4j.framework.core.xml.Element;

/**
 * This class corresponds to  &ltRTProperties&gt element of the
 * SyncML DM Description Framework DTD.
 * Content model: (ACL, Format, Name, Size?, Title?, TStamp?, Type?, VerNo?)>
 *
 * @author	<a href="mailto:sso@users.sourceforge.net">Simon So</a>
 * @since	SyncML 1.1
 */
public class RTProperties extends BaseElement
{
    private String m_acl;
    
    private final Format m_format;
    
    private final String m_name;
    
    private final String m_size;
    
    private final String m_title;
    
    private final String m_tStamp;
    
    private final Type m_type;
    
    private final String m_verNo;
    
    /**
     *	Constructs a runtime properties.
     */
    public RTProperties(final String acl,
			final Format format,
			final String name,
			final String size,
			final String title,
			final String tStamp,
			final Type type,
			final String verNo)
    {
	if (acl == null)
	{
	    throw new NullPointerException("ACL of RTProperties");
	}
	
	if (name == null)
	{
	    throw new NullPointerException("name of RTProperties");
	}
	
	try
	{
	    Byte.parseByte(size);
	    
	    // 7.4.2.8
	    Short.parseShort(verNo);
	}
	catch (NumberFormatException nfe)
	{
	    throw new IllegalArgumentException(nfe.getMessage());
	}
	
	// todo: verify tStamp
	m_acl = acl;
	m_format = format;
	m_name = name;
	m_size = size;
	m_title = title;
	m_tStamp = tStamp;
	m_type = type;
	m_verNo = verNo;
    }
    
    /**
     * Constructs a run time property from a JDOM element.
     *
     * @param e	an element from a JDOM tree.
     */
    public RTProperties(Element e) throws RepresentationException
    {
	this(Util.extractElementText(e, "ACL", true),
	    Format.extractFrom(e, "Format"),
	    Util.extractElementText(e, "Name", true),
	    Util.extractElementText(e, "Size", false),
	    Util.extractElementText(e, "Title", false),
	    Util.extractElementText(e, "TStamp", false),
	    Type.extractFrom(e, "Type"),
	    Util.extractElementText(e, "VerNo", false));
    }
    
    public String getAcl()
    {
	return m_acl;
    }
    
    public void setAcl(final String acl)
    {
	m_acl = acl;
    }
    
    public Format getFormat()
    {
	return m_format;
    }
    
    public String getName()
    {
	return m_name;
    }
    
    public String getSize()
    {
	return m_size;
    }
    
    public String getTitle()
    {
	return m_title;
    }
    
    public String getTStamp()
    {
	return m_tStamp;
    }
    
    public Type getType()
    {
	return m_type;
    }
    
    public String getVerNo()
    {
	return m_verNo;
    }
    
    /**
     * Returns an XML representation of the tag.  Uses string literals
     * so that the code will always look from the string pool instead
     * of dynamically creating the tag by reflection and wasting resources.
     *
     * @return	an XML representation of the tag.
     */
    public String toXML()
    {
	StringBuffer body = new StringBuffer();
	
	body.append("<RTProperties>");
	
	body.append("<ACL>").append(m_acl).append("</ACL>\n");
	
	body.append(m_format.toXML());
	
	body.append("<Name>").append(m_name).append("</Name>\n");
	
	if (m_size != null)
	{
	    body.append("<Size>").append(m_size).append("</Size>\n");
	}
	
	if (m_title != null)
	{
	    body.append("<Title>").append(m_title).append("</Title>\n");
	}
	
	if (m_tStamp != null)
	{
	    body.append("<TStamp>").append(m_tStamp).append("</TStamp>\n");
	}
	
	if (m_type != null)
	{
	    body.append(m_type.toXML());
	}
	
	if (m_verNo != null)
	{
	    body.append("<VerNo>").append(m_verNo).append("</VerNo>\n");
	}
	
	body.append("</RTProperties>\n");
	
	return body.toString();
    }
    
    static RTProperties extractFrom(Element eParent)
	    throws RepresentationException
    {
	Element e = Util.extractElement(eParent,
					    "RTProperties",
					    false);
	
	return (e != null) ? new RTProperties(e) : null;
    }
}
