/*
 
 $Id: Scope.java,v 1.2 2002/12/26 18:10:15 stefano_fornari Exp $
 
 Copyright (c) 2001-2002 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.
 
 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:
 
     "This product includes software developed by the
      sync4j project."
 
 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.
 
 */

package sync4j.framework.dm;

import sync4j.framework.core.*;
import sync4j.framework.core.xml.Element;

/**
 * This class corresponds to  &ltScope&gt element
 * of the SyncML DM Description Framework DTD.
 *
 * Content model: (Permanent | Dynamic)
 *
 * @author	<a href="mailto:sso@users.sourceforge.net">Simon So</a>
 * @since	SyncML 1.1
 */
public final class Scope extends BaseElement
{
    public static final String PERMANENT = "Permanent";
    public static final String DYNAMIC = "Dynamic";
    
    private String	m_scope = DYNAMIC;

    /**
     * Constructs a scope object.
     *
     * @throws IllegalArgumentException if s is neither Permanent or Dynamic.
     */
    public Scope(String s) throws IllegalArgumentException
    {
	if (!s.equals(DYNAMIC) && !s.equals(PERMANENT))
	{
	    throw new IllegalArgumentException(
			    "The scope value must be either "
			    + PERMANENT + " or " + DYNAMIC);
	}
	
	m_scope = s;
    }
    
    public String getScope()
    {
	return m_scope;
    }
    
    public String toXML()
    {
	StringBuffer body = new StringBuffer();
	
	body.append("<Scope>").append(m_scope).append("</Scope>\n");
	
	return body.toString();
    }

    /**
     * Extracts &ltScope&gt.  If it is found, its child must be either 
     * &ltPermanent&gt or &ltDynamic&gt.
     *
     * @throws RepresentationException if &ltScope&gt cannot be extracted,
     *					or it designated child is not present.
     */
    public static Scope extractFrom(Element eParent)
	throws RepresentationException
    {
	try
	{
	    Element e = Util.extractElement(eParent, "Scope", false);
	    if (e != null)
	    {
		Element child = Util.extractElement(e, PERMANENT, false);
		if (child == null)
		{
		    //	will throw exception if it has problems
		    child = Util.extractElement(e, DYNAMIC, false);
		}
		return new Scope(child.getName());
	    }
	    
	    // 7.4.3.6
	    return new Scope(DYNAMIC);
	}
	catch (Exception ex)
	{
	    throw new RepresentationException(ex.getMessage());
	}
    }
}
