/*
 
 $Id: Type.java,v 1.4 2003/12/23 12:50:07 luigiafassina Exp $
 
 Copyright (c) 2001-2002 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.
 
 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:
 
     "This product includes software developed by the
      sync4j project."
 
 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.
 
 */

package sync4j.framework.dm;

import sync4j.framework.core.xml.Element;
import sync4j.framework.core.*;

import java.util.Enumeration;
import java.util.Vector;

/**
 * This class represents either
 *
 *	&lt!ELEMENT Type(MIME)&gt
 *  or
*	&lt!ELEMENT DFType(MIME+)&gt
 *
 * @author  <a href="mailto:sso@users.sourceforge.net">Simon So</a>
 * @since   SyncML 1.1
 */
public final class Type extends BaseElement
{
    
    /** Creates new type */
    private final String[] m_mime;
    private final String m_tag;
    
    public Type(final String[] m, String tag)
    {
        if (tag.equals("DFType"))
        {
            // 7.4.3.8 the values MUST be registered MIME types
        }
        m_mime = m;
        m_tag = tag;
    }
    
    public String[] getMime()
    {
    	return m_mime;
    }
    
    public String getTag()
    {
	    return m_tag;
    }
    
    /**
     *	Extracts a &ltType&gt or &ltDFType&gt from a JDOM element.
     *
     *	@param	eParent
     *	@param	tag the tag string, either <Type> or <DFType>
     *	@return	a Type object; usable for DFType also
     *	@see	RTProperties#RTProperties(Element)
     *	@see	DFProperties#DFProperties(Element)
     */
    static Type extractFrom(final Element eParent, final String tag)
	    throws RepresentationException
    {
        Element dfe = Util.extractElement(eParent, tag, false);
        if (dfe != null)
        {
            Vector v = new Vector();
            for (Enumeration enum=eParent.getChildren(); enum.hasMoreElements();)
            {
                // adding each <MIME>...</MIME>
                v.addElement((Util.castToElement(enum.nextElement())).getText());
            }
            
            int size = v.size();
            String [] aTypes = new String[size];
            for (int i=0; i < size; i++) {
                aTypes[i] = (String)v.elementAt(i);
            }
            return new Type(aTypes, tag);
        }
        
        return null;
    }
    
    public String toXML()
    {
        StringBuffer body = new StringBuffer();
        
        body.append("<").append(m_tag).append(">");
        
        for (int i=0; i < m_mime.length; i++)
        {
            body.append("<MIME>").append(m_mime[i]).append("</MIME>\n");
        }
        
        body.append("</").append(m_tag).append(">\n");
        
        return body.toString();
    }
}
