/*
 Copyright (c) 2001-2003 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.  
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

*/
package sync4j.framework.engine;

import sync4j.framework.core.Sync4jException;
import sync4j.framework.security.Sync4jPrincipal;
import sync4j.framework.engine.SyncStrategy;

/**
 * A synchronization engine represents a mechanism used to drive the syncrhonization 
 * process.<br>
 * <i>SyncEngine</i> represents the Context partecipant of the Strategy pattern.<br>
 * It is a sort of factory and manager for the starategy object referenced by
 * the property <i>strategy</i> (that implementing classes must provide).<p>
 * <i>SyncEngine</i> concentrate all the implementation specific information 
 * regarding strategies, sources, databases, services, etc. It is the point of
 * contact between the synchronization, protocol and server services.
 * <p>
 * When a synchronization process must take place, the <i>SyncEngine</i> will 
 * pass the control to the configured strategy, which has the responsability of
 * query item sources in order to define which synchronization operations are 
 * required. Then the synchronization operations are applied to the sources.
 *
 * @see SyncStrategy
 *
 * @author Stefano Fornari @ Funambol
 *
 * @version $Id: SyncEngine.java,v 1.6 2003/12/15 16:56:35 luigiafassina Exp $
 */
public interface SyncEngine {
    
    /**
     * Get the underlying strategy
     *
     * @return the underlying strategy
     */
    public SyncStrategy getStrategy();
    
    /**
     * Set the synchronization strategy to be used
     */
    public void setStrategy(SyncStrategy strategy);
    
    /**
     * Fires and manages the synchronization process.
     *
     * @throws Sync4jException in case of error
     */
    public void sync(Sync4jPrincipal principal) throws Sync4jException;    
}
