/*
 Copyright (c) 2001 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.  
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */


package sync4j.framework.engine;

/**
 * This class represents a unique identifier of a <i>SyncItem</i> item in a repository.
 *
 * @author Stefano Fornari @ Funambol
 *
 * @version $Id: SyncItemKey.java,v 1.5 2003/01/23 22:33:39 stefano_fornari Exp $
 */
public class SyncItemKey implements java.io.Serializable {
    
    // -------------------------------------------------------------- Properties
    
    /**
     * The key value
     */
    private Object keyValue = null;
    public Object getKeyValue(){
        return keyValue;
    }
    
    /**
     * @param keyValue the key - NOT NULL (assert checked)
     */
    public void setKeyValue(Object keyValue){
        assert (keyValue != null);
        this.keyValue = keyValue; 
    }
    
    // ------------------------------------------------------------ Constructors
    
    /**
     * @param keyValue the key - NOT NULL (assert checked)
     */
    public SyncItemKey(Object keyValue) {
        assert (keyValue != null);
        this.keyValue = keyValue;
    }
    
    // ---------------------------------------------------------- Public Methods
    
    /**
     * @return this key's value as a String object (calling toString() on the
     *         value object)
     */
    public String getKeyAsString() {
        return keyValue.toString();
    }
    
    /**
     * Two keys are equal if their keyValues are equal
     *
     * @param o the object this instance must be compared to.
     *
     * @return the given object is equal to this object
     */
    public boolean equals(Object o) {
        if (!(o instanceof SyncItemKey)) return false;
        
        return ((SyncItemKey)o).getKeyValue().equals(keyValue);
    }
    
    /**
     * @return a string representation for debugging purposes of this <i>SyncItemKey</i>.
     */
    public String toString() {
        StringBuffer sb = new StringBuffer(getClass().getName());
        
        sb.append( " { "            );
        sb.append( " keyValue: "    );
        sb.append( getKeyAsString() );
        sb.append( " } "            );
        
        return sb.toString();
    }
}
