/*
 Copyright (c) 2001-2002-2003 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.  
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */
package sync4j.framework.engine;

import java.security.Principal;

import sync4j.framework.engine.SyncItem;

/**
 * This interface represents a synchronization operation between two items. 
 * The possible operations are:
 * <ul>
 * <li>create
 * <li>update
 * <li>delete
 * </ul>
 *
 * @author Stefano Fornari @ Funambol
 *
 * @version $Id: SyncOperation.java,v 1.8 2003/10/13 09:32:47 luigiafassina Exp $
 */
public interface SyncOperation {
    
    public static final char NEW      = 'N';
    public static final char DELETE   = 'D';
    public static final char UPDATE   = 'U';
    public static final char CONFLICT = 'O';
    public static final char NOP      = '-';
    
    public SyncItem getSyncItemA();
    public void setSyncItemA(SyncItem syncItemA);
    
    public SyncItem getSyncItemB();    
    public void setSyncItemB(SyncItem syncItemB);
    
    /**
     * Does the operation apply to the client source
     *
     * @return true if the operation applies to the client source or false otherwise.
     */
    public boolean isAOperation();
    public void setAOperation(boolean a);
    
    /**
     * Does the operation apply to the server source*
     *
     * @return true if the operation applies to the server source or false otherwise.
     */
    public boolean isBOperation();
    public void setBOperation(boolean b);
    
    public char getOperation();
    
    /**
     * The principal that requested this operation. 
     *
     * @return the principal that requested this operation. It may be null.
     */
    public Principal getOwner();
}
