/*
 Copyright (c) 2001-2002-2003 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.  
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */
package sync4j.framework.engine;

import java.security.Principal;

import sync4j.framework.engine.SyncItem;
import sync4j.framework.engine.SyncOperation;

import org.apache.commons.lang.builder.ToStringBuilder;


/**
 * This class is a concrete implementation of <i>SyncOperation</i>
 * <p>
 * The property <i>operation</i> contains the type of the operation to perform
 * and the not null syncItemX selects on what source the operation has to be
 * applied.
 *
 * @author Stefano Fornari @ Funambol
 *
 * @version $Id: SyncOperationImpl.java,v 1.4 2003/08/23 19:02:49 stefano_fornari Exp $
 */
public class SyncOperationImpl implements SyncOperation {
    
    // -------------------------------------------------------------- Properties
    
    private SyncItem syncItemA = null;
    public SyncItem getSyncItemA() {
        return this.syncItemA;
    }
    
    public void setSyncItemA(SyncItem syncItemA) {
        this.syncItemA = syncItemA;
    }
    
    private SyncItem syncItemB = null;
    public SyncItem getSyncItemB() {
        return this.syncItemB;
    }
    
    public void setSyncItemB(SyncItem syncItemB) {
        this.syncItemB = syncItemB;
    }
    
    private char operation = 0;
    public char getOperation() {
        return this.operation;
    }
    
    private Principal owner = null;
    
    /** The principal that requested this operation.
     *
     * @return the principal that requested this operation. It may be null.
     *
     */
    public Principal getOwner() {
        return this.owner;
    }
    
    /**
     * Set the owner of this operation
     */
    public void setOwner(Principal owner) {
        this.owner = owner;
    }
    
    private boolean aOperation = false;
    
    /** Getter for property aOperation.
     * @return Value of property aOperation.
     *
     */
    public boolean isAOperation() {
        return aOperation;
    }
    
    /** Setter for property aOperation.
     * @param aOperation New value of property aOperation.
     *
     */
    public void setAOperation(boolean aOperation) {
        this.aOperation = aOperation;
    }
    
    private boolean bOperation = false;
    
    /** Getter for property bOperation.
     * @return Value of property bOperation.
     *
     */
    public boolean isBOperation() {
        return bOperation;
    }
    
    /** Setter for property bOperation.
     * @param bOperation New value of property aOperation.
     *
     */
    public void setBOperation(boolean bOperation) {
        this.bOperation = bOperation;
    }
        
    // ------------------------------------------------------------ Constructors
    
    public SyncOperationImpl() {
    }
    
    /**
     * Create a new SyncOperationImpl
     *
     * @param syncItemA the A item
     * @param syncItemB the B item
     * @param operation the operation
     * @param aOperation is an operation to be performed on source A?
     * @param bOperation is an operation to be performed on source B?
     */
    public SyncOperationImpl(Principal owner     , 
                             SyncItem  syncItemA , 
                             SyncItem  syncItemB , 
                             char      operation ,
                             boolean   aOperation,
                             boolean   bOperation) {
        this.owner      = owner    ;
        this.syncItemA  = syncItemA;
        this.syncItemB  = syncItemB;
        this.operation  = operation;
        this.aOperation = aOperation;
        this.bOperation = bOperation;
    }

    public SyncOperationImpl(SyncItem syncItemA, 
                             SyncItem syncItemB, 
                             char     operation) {
        //
        // owner can be set later...
        //
        this(null, syncItemA, syncItemB, operation, false, false);
    }
    
    // ---------------------------------------------------------- Public methods
    
    public String toString() {
        ToStringBuilder b = new ToStringBuilder(this);

        b.append("A", "" + syncItemA);
        b.append("B", "" + syncItemB);
        String o = "";
        switch (operation) {
            case NEW :     o = "NEW"     ; break;
            case DELETE:   o = "DELETE"  ; break;
            case UPDATE:   o = "UPDATE"  ; break;
            case CONFLICT: o = "CONFLICT"; break;
            case NOP:      o = "NOP"     ; break;
        }
        b.append("operation", o);
        b.append("isAOperation", String.valueOf(aOperation));
        b.append("isBOperation", String.valueOf(bOperation));
        
        return b.toString();
    }        
}

