/*
 Copyright (c) 2001 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.  
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */

package sync4j.framework.engine;

import sync4j.framework.engine.SyncOperation;
import sync4j.framework.engine.source.SyncSource;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * This is a base implementation of a <i>SyncOperationStatus</i>
 *
 * @author  Stefano Fornari @ Funambol
 * @version $Id: SyncOperationStatusImpl.java,v 1.2 2003/04/19 10:33:02 stefano_fornari Exp $
 *
 */
public abstract class SyncOperationStatusImpl implements SyncOperationStatus {
    
    // -------------------------------------------------------------- Properties
    
    /**
     * The operation this object represents the execution for
     */
    private SyncOperation operation = null;
    
    /** Getter for property operation.
     * @return Value of property operation.
     *
     */
    public SyncOperation getOperation() {
        return operation;
    }
    
    /**
     * The source the operation was executed on
     */
    private SyncSource syncSource = null;
    
    /** Getter for property syncSource.
     * @return Value of property syncSource.
     *
     */
    public SyncSource getSyncSource() {
        return syncSource;
    }
        
    
    // ------------------------------------------------------------- Contructors
    
    /** 
     * Creates a new instance of SyncOperationStatus
     * 
     * @param operation the operation - NOT NULL
     * @param syncSource the source - NOT NULL
     *
     * @throws IllegalArgumentException in case operation is null
     */
    public SyncOperationStatusImpl(SyncOperation operation, SyncSource syncSource) {
        if (operation == null) {
            throw new IllegalArgumentException("operation cannnot be null");
        }
        if (syncSource == null) {
            throw new IllegalArgumentException("syncSource cannnot be null");
        }
        
        this.operation  = operation ;
        this.syncSource = syncSource;
    }
       
    // ---------------------------------------------------------- Public methods

    public String toString() {
        return new ToStringBuilder(this).
            append("operation",  operation.toString() ).
            append("syncSource", syncSource.toString()).
            toString();
    }
    
    /** The operation status code
     * @return the operation status code
     *
     */
    abstract public int getStatusCode();
    
}
