/*
 Copyright (c) 2001-2003 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.  
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */
package sync4j.framework.engine;

import java.util.ArrayList;

/**
 * @author Stefano Fornari @ Funambol
 *
 * @version $Id: Util.java,v 1.2 2003/07/03 17:01:31 stefano_fornari Exp $
 */
public final class Util {
    /**
     * Creates an array of Boolean starting from an array of strings
     *
     * @param       string_values   array of value to be converted
     *
     * @return      an array of Boolean
     */
    public static boolean[] createArrayOfBooleans(String[] string_values) {
        boolean[] array = new boolean[string_values.length];

        for(int i=0; i<string_values.length; ++i) {
            array[i] = Boolean.getBoolean(string_values[i]);
        }  // next i

        return array;
    } // createArrayOfBooleans

    /**
     * Creates an array of Character starting from an array of strings
     *
     * @param       string_values   array of value to be converted
     *
     * @return      an array of Character
     */
    public static char[] createArrayOfCharacters(String[] string_values) {
        char[] array = new char[string_values.length];

        for(int i=0; i<string_values.length; ++i) {
            array[i] = (string_values[i].length()>0) ? string_values[i].charAt(0) : ' ';
        }  // next i

        return array;
    } // createArrayOfCharacters

    /**
     * Creates an array of Double starting from an array of strings
     *
     * @param       string_values   array of value to be converted
     *
     * @return      an array of Double
     */
    public static double[] createArrayOfDoubles(String[] string_values) {
        double[] array = new double[string_values.length];

        for(int i=0; i<string_values.length; ++i) {
            array[i] = Double.parseDouble(string_values[i]);
        }  // next i

        return array;
    } // createArrayOfDoubles

    /**
     * Creates an array of Float starting from an array of strings
     *
     * @param       string_values   array of value to be converted
     *
     * @return      an array of Float
     */
    public static float[] createArrayOfFloats(String[] string_values) {
        float[] array = new float[string_values.length];

        for(int i=0; i<string_values.length; ++i) {
            array[i] = Float.parseFloat(string_values[i]);
        }  // next i

        return array;
    } // createArrayOfFloats

    /**
     * Creates an array of Integer starting from an array of strings
     *
     * @param       string_values   array of value to be converted
     *
     * @return      an array of int
     */
    public static int[] createArrayOfIntegers(String[] string_values) {
        int[] array = new int[string_values.length];

        for(int i=0; i<string_values.length; ++i) {
            array[i] = Integer.parseInt(string_values[i]);
        }  // next i

        return array;
    } // createArrayOfIntegers

    /**
     * Creates an array of Long starting from an array of strings
     *
     * @param       string_values   array of value to be converted
     *
     * @return      an array of Long
     */
    public static long[] createArrayOfLongs(String[] string_values) {
        long[] array = new long[string_values.length];

        for(int i=0; i<string_values.length; ++i) {
            array[i] = Long.parseLong(string_values[i]);
        }  // next i

        return array;
    } // createArrayOfLongs

    // =========================================================================

    /**
     * Makes a string concatenating the capitalized version of the given words.<p>
     *
     * For example:
     * <pre>
     * Util.makeCapitalizedString(new String[] { "bean", "blue" });
     * </pre>
     * will return <pre>BeanBlue</pre>.<p>
     *
     * null strings in the <i>words</i> array will be silenty ignored.
     *
     * @param   words     the strings to capitalize and concatenate
     *
     * @return  the capitalized string
     *
     */
    public static String makeCapitalizedString(String[] words) {
        StringBuffer sb = new StringBuffer();

        for(int i=0; i<words.length; ++i) {
            if (words[i] != null) sb.append(capitalizeWord(words[i]));
        }  // next i

        return sb.toString();
    }

    /**
     * Capitalizes a word.<p>
     *
     * For example:
     * <pre>
     * Util.capitalizeWord("bean");
     * </pre>
     * will return <pre>Bean</pre>.
     *
     * @param   word    the word to capitalize
     *
     * @return  the capitalized word
     */
    public static String capitalizeWord(String word) {
        int len = word.length();

        if (len == 1) return word.toUpperCase();

        return word.substring(0, 1).toUpperCase() +
               word.substring(1   )               ;
    }
    
    /**
     * Returns a string representation of an array of Objects. It translates
     * the array in an ArrayList and then invokes toString().
     *
     * @param array     the array
     *
     * @return the string representation of the given array
     */
    public static String arrayToString(Object[] array) {
        ArrayList arrayList = new ArrayList();
        
        for (int i=0; i<array.length; ++i) {
            arrayList.add(array[i]);
        }
        
        return arrayList.toString();
    }
}