/*
 Copyright (c) 2003-2004 sync4j project
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.

 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.

 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */

package sync4j.framework.engine.pipeline;

import java.io.Serializable;
import java.util.logging.Logger;
import java.util.logging.Level;

import sync4j.framework.logging.Sync4jLogger;

import sync4j.framework.core.Message;
import sync4j.framework.core.Sync4jException;

/** 
 * This class represents the manager of the pipeline. It supplies a hook for adding
 * additional processing and manipulation of the message between the server and the
 * client.
 */
public class PipelineManager implements InputMessageProcessor, OutputMessageProcessor, Serializable {

    // --------------------------------------------------------------- Constants

    // ------------------------------------------------------------ Private data

    private static final Logger log = Sync4jLogger.getLogger("engine");
    
    // ------------------------------------------------------------ Constructors

    // -------------------------------------------------------------- Properties

    private InputMessageProcessor  inputProcessors[]  = null;
    private OutputMessageProcessor outputProcessors[] = null;
   
    /** Getter for property inputProcessors.
     * @return Value of property inputProcessors.
     */
    public InputMessageProcessor[] getInputProcessors() {
        return this.inputProcessors;
    }

    /** Setter for property inputProcessors.
     * @param inputProcessors New value of property inputProcessors.
     */
    public void setInputProcessors(InputMessageProcessor[] inputProcessors) {
        this.inputProcessors = inputProcessors;
    }

    /** Getter for property outputProcessors.
     * @return Value of property outputProcessors.
     */
    public OutputMessageProcessor[] getOutputProcessors() {
        return this.outputProcessors;
    }

    /** Setter for property outputProcessors
     * @param outputProcessors New value of property outputProcessors.
     */
    public void setOutputProcessors(OutputMessageProcessor[] outputProcessors) {
        this.outputProcessors = outputProcessors;
    }

    // ---------------------------------------------------------- Public methods

	public PipelineManager() {
    }
    
    /** Process the message with the input processors.
     * @param processingContext message processing context
     * @param message the message to be processed
     */    
    public void preProcessMessage(MessageProcessingContext processingContext, Message message) {
        if (log.isLoggable(Level.FINE)) {
            log.fine("Starting preprocessing");
        }
        
		//cycle on inputMessageProcessor[] elements
		int size = inputProcessors.length;  
        for (int i=0; i<size; i++) {
            try {
                inputProcessors[i].preProcessMessage(processingContext, message);
            } catch(Sync4jException e) {
                log.info("preProcessMessage error: " + e);
            }
        }
    }

    /** Process the message with the output processors.
     * @param processingContext message processing context
     * @param message the message to be processed
     */    
    public void postProcessMessage(MessageProcessingContext processingContext, Message message) {
        if (log.isLoggable(Level.FINE)) {
            log.fine("Starting postprocessing");
        }
        
		//cycle on outputMessageProcessor[] elements
		int size = outputProcessors.length;       
		for (int i=0; i<size; i++) {
            try {
                outputProcessors[i].postProcessMessage(processingContext, message);
            } catch(Sync4jException e) {
                log.info("postProcessMessage error: " + e);
            }
		}
    }
        
}
