/*
 Copyright (c) 2001-2003 sync4j project
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.

 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.

 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */

package sync4j.framework.engine.source;

import java.security.Principal;
import java.sql.Timestamp;

import sync4j.framework.engine.*;
import sync4j.framework.engine.source.SyncSource;

/**
 * Implements the basic functionalities of a <i>SyncSource</i> like naming.
 *
 * @author  Stefano Fornari @ Funambol
 *
 * @version $Id: AbstractSyncSource.java,v 1.14 2003/12/22 11:58:41 stefano_fornari Exp $
 */
public abstract class AbstractSyncSource implements SyncSource, java.io.Serializable {
    // --------------------------------------------------------------- Constants

    public static final String LOG_NAME = "source";

    // ---------------------------------------------------------- Protected data

    protected String name       = null;
    protected String type       = null;
    protected String sourceURI  = null;
    protected SyncSourceInfo info      = null;

    // ------------------------------------------------------------ Constructors

    /** Creates a new instance of AbstractSyncSource */
    protected AbstractSyncSource() {
    }

    public AbstractSyncSource(String name, String type, String sourceURI) {
        if (name == null) {
            throw new NullPointerException("name is null!");
        }

        this.name      = name;
        this.type      = (type == null) ? "unknown" : type;
        this.sourceURI = sourceURI;
    }

    public AbstractSyncSource(String name) {
        this(name, null, null);
    }

    // ---------------------------------------------------------- Public methods

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getType() {
        return this.type;
    }

    public void setType(String type) {
        this.type = type;
    }

    /** Getter for property uri.
     * @return Value of property uri.
     */
    public String getSourceURI() {
        return sourceURI;
    }

    /** Setter for property uri.
     * @param sourceURI New value of property uri.
     */
    public void setSourceURI(String sourceURI) {
        this.sourceURI = sourceURI;
    }

    /** Returns the type info of the content handled by this source
     *
     * @return the type info of the content handled by this source
     *
     */
    public SyncSourceInfo getInfo() {
        return this.info;
    }
    
    /**
     * Setter for the property <i>info</i>
     */
    public void setInfo(SyncSourceInfo info) {
        this.info = info;
    }

    /**
     * Returns a string representation of this object.
     *
     * @return a string representation of this object.
     */
    public String toString() {
        StringBuffer sb = new StringBuffer(super.toString());

        sb.append(" - {name: ").append(getName()     );
        sb.append(" type: "   ).append(getType()     );
        sb.append(" uri: "    ).append(getSourceURI());
        sb.append("}"         );

        return sb.toString();
    }

    public void beginSync(int syncMode) throws SyncSourceException {
    }
    
    public void endSync() throws SyncSourceException {
    }

    // -------------------------------------------------------- Abstract methods

    public abstract SyncItem[] getAllSyncItems(Principal principal) throws SyncSourceException;

    public abstract SyncItemKey[] getDeletedSyncItemKeys(Principal principal,
                                                         Timestamp since    ) throws SyncSourceException;

    public abstract SyncItem[] getDeletedSyncItems(Principal principal,
                                                   Timestamp since    ) throws SyncSourceException;

    public abstract SyncItemKey[] getNewSyncItemKeys(Principal principal,
                                                     Timestamp since    ) throws SyncSourceException;

    public abstract SyncItem[] getNewSyncItems(Principal principal,
                                               Timestamp since    ) throws SyncSourceException;

    public abstract SyncItem getSyncItemFromId(Principal principal, SyncItemKey syncItemKey) throws SyncSourceException;
    
    public abstract SyncItem[] getSyncItemsFromIds(Principal principal, SyncItemKey[] syncItemKeys) throws SyncSourceException;

    public abstract SyncItem[] getUpdatedSyncItems(Principal principal,
                                                   Timestamp since    ) throws SyncSourceException;

    public abstract void removeSyncItem(Principal principal, SyncItem syncItem) throws SyncSourceException;

    public abstract void removeSyncItems(Principal principal, SyncItem[] syncItems) throws SyncSourceException;

    public abstract SyncItem setSyncItem(Principal principal, SyncItem syncInstance) throws SyncSourceException;

    public abstract SyncItem[] setSyncItems(Principal principal, SyncItem[] syncItems) throws SyncSourceException;
    
    public abstract SyncItem getSyncItemFromTwin(Principal principal, SyncItem syncItem) throws SyncSourceException;
    
    public abstract SyncItem[] getSyncItemsFromTwins(Principal principal, SyncItem[] syncItems) throws SyncSourceException;
}
