/*

 Copyright (c) 2001-2003 sync4j project
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.

 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.

 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

*/
package sync4j.framework.engine.source;

import sync4j.framework.engine.source.ContentType;

/**
 * This class wraps the following information about a <i>SyncSource</i>
 * <table>
 * <tr>
 * <td>supportedTypes</td>
 * <td>Types supported by a source</td>
 * </tr>
 * <tr>
 * <td>preferredType</td>
 * <td>The preferred source content type</td>
 * </tr>
 * </table>
 *
 * @author  Stefano Fornari
 */
public class SyncSourceInfo implements java.io.Serializable {
    
    // -------------------------------------------------------------- Properties
    
    private ContentType[] supportedTypes = null;
    
    /** Getter for property supportedTypes.
     * @return Value of property supportedTypes.
     *
     */
    public ContentType[] getSupportedTypes() {
        return this.supportedTypes;
    }    
    
    /** Setter for property supportedTypes.
     * @param supportedTypes New value of property supportedTypes.
     *
     */
    public void setSupportedTypes(ContentType[] supportedTypes) {
        this.supportedTypes = supportedTypes;
        this.preferred  = 0;
    }    
    
    /**
     * The preferred content type index
     **/
    private int preferred = 0;
    
    /** Getter for property preferred.
     * @return Value of property preferred.
     *
     */
    public int getPreferred() {
        return preferred;
    }
    
    /** Setter for property preferredType.
     * @param preferred New value of property preferredType.
     *
     */
    public void setPreferred(int preferred) {        
        this.preferred = preferred;
    }
    
    /**
     * Returns the preferred content type among the supported ones.
     *
     * @return the preferred content type among the supported ones.
     *
     */
    public ContentType getPreferredType() {
        assert ((supportedTypes != null) && (preferred >= 0) && (preferred < supportedTypes.length));
        return supportedTypes[preferred];
    }
    
    // ------------------------------------------------------------ Constructors
    /** 
     * Creates a new instance of SyncSuurceInfo 
     *
     * @param supportedTypes - NOT NULL or EMPTY
     * @param preferred the position in the <i>supportedTypes</i> array of the 
     *                  preferred type
     *
     * @throws IllegalArgumentException if the passed in parameters are not correct
     */
    public SyncSourceInfo(ContentType[] supportedTypes, int preferred) {
        if ((supportedTypes == null) || (supportedTypes.length == 0)) {
            throw new IllegalArgumentException("supportedTypes cannot be null");
        }
        
        if ((preferred<0) || (preferred >= supportedTypes.length)) {
            throw new IllegalArgumentException( "preferred is "
                                              + preferred
                                              + " when the supported type are "
                                              + supportedTypes.length);
        }
        
        this.supportedTypes = supportedTypes;
        this.preferred = preferred;
    }
    
    public SyncSourceInfo() {
    }
}
