/*

 $Id: Sync4jLogger.java,v 1.5 2003/12/15 16:56:50 luigiafassina Exp $

 Copyright (c) 2001-2002-2003 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.  
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */

package sync4j.framework.logging;

import java.util.logging.Logger;

/**
 * Provides a common logging facility for the framework. 
 * <p>
 * The verbosity of the log can be set in the JDK logging properties files
 * giving one of the following values (case insensitively):
 * <ul>
 *   <li>SEVERE
 *   <li>WARNING
 *   <li>INFO
 *   <li>CONFIG
 *   <li>FINE
 *   <li>FINER
 *   <li>FINEST
 *   <li>ALL
 * </ul>
 *
 * For example, for the Sync4j default logger, you can specify:
 * <pre>
 *   sync4j.level=SEVERE
 * </pre>
 * @author  Stefano Fornari @ Funambol.com
 */
public class Sync4jLogger {
    
    public static final String LOG_NAME = "sync4j";
    
    /**
     * Returns the Sync4j default logger
     *
     * @return the Sync4j default logger
     */
    public static Logger getLogger() {
        return Logger.getLogger(LOG_NAME);
    }
    
    /**
     * Returns the logger associated with the name <i>LOG_NAME</i>.name.
     *
     * @param name the subname of the logger.
     *
     * @return the logger associated with the name <i>LOG_NAME</i>.name.
     */
    public static Logger getLogger(String name) {
        return Logger.getLogger(LOG_NAME + '.' + name);
    } 
}
