/*

 Copyright (c) 2001 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.  
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */

package sync4j.framework.server;

import org.apache.commons.lang.builder.ToStringBuilder;


/**
 * Represents a synchronization timestamp for a particular database and principal.
 * <i>tag</i> stores the next (when used as a next timestamp) or the last (when 
 * used as a last timstamp) value as it appears in <i>SyncAnchor</i>.
 *
 * @author  Stefano Fornari @ Funambol
 * @version $Id: SyncTimestamp.java,v 1.1 2003/04/08 20:41:22 stefano_fornari Exp $
 */
public class SyncTimestamp {
    
    // ------------------------------------------------------------- Public data
    
    public long   start    = -1  ;  // timestamp of when sync started
    public long   end      = -1  ;  // timestamp of when sync ended
    public String tag       = null;  // the last/next tag
    
    // ------------------------------------------------------------ Constructors
    
    /** Creates a new instance of LastTimestamp */
    public SyncTimestamp() { }
    
    /** Creates a new instance of LastTimestamp */
    public SyncTimestamp(final String tag  , 
                         final long   start, 
                         final long   end  ) {
        this.tag      = tag      ;
        this.start    = start    ;
        this.end      = end      ;
    }
    
    // ---------------------------------------------------------- Public methods
    
    public String toString() {
        ToStringBuilder sb = new ToStringBuilder(this);
        
        sb.append("tag"      , tag).
           append("start"    , new java.sql.Timestamp(start)).
           append("end"      , new java.sql.Timestamp(end));
        return sb.toString();
    }
}
