/*

 $Id: ServerException.java,v 1.1 2002/12/26 17:43:20 stefano_fornari Exp $

 Copyright (c) 2001-2002 sync4j project
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.

 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.

 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */

package sync4j.framework.server.error;

import sync4j.framework.core.StatusCode;
import sync4j.framework.core.Sync4jException;

/**
 * @version $Id: ServerException.java,v 1.1 2002/12/26 17:43:20 stefano_fornari Exp $
 * @author  Stefano Fornari @ Funambol
 */
public class ServerException extends Sync4jException {
    
    // --------------------------------------------------------------- Constants
    
    public static int UNKNOWN = -1;
    
    // ------------------------------------------------------------ Private data
    
    private int statusCode = UNKNOWN;
    
    // ------------------------------------------------------------ Constructors

    /**
     * @param strMsg  human readable String that describes the cause of the
     *      exception
     */
    public ServerException(final String strMsg) {
        super(strMsg);
    }

    /**
     * Constructor for the ServerException object
     *
     * @param statusCode  Description of the Parameter
     * @param strMsg      Description of the Parameter
     */
    public ServerException(final int statusCode, final String strMsg) {
        this(statusCode, strMsg, null);
    }

    public ServerException(final String strMsg, final Throwable cause) {
        this(UNKNOWN, strMsg, cause);
    }
    
    public ServerException(final int statusCode, final String strMsg, final Throwable cause) {
        super(strMsg, cause);
        
        this.statusCode = statusCode;
    }
    
    public ServerException(final Throwable cause) {
        this(UNKNOWN, "", cause);
    }
    
    // ---------------------------------------------------------- Public methods
    
    /**
     * Gets the statusCode attribute of the ServerException object
     *
     * @return   The statusCode value
     */
    public int getStatusCode() {
        return statusCode;
    }

    
    /**
     * Returns the SyncML message associated to the status code of this exception
     *
     * @return the SyncML message associated to the status code of this exception
     */
    public String getSyncMLMessage() {
        int code = getStatusCode();
        
        String msg = StatusCode.getStatusDescription(code);
        
        return (msg == null) ? "" : msg;
    }
    
    /**
     * Redefines the standard <i>getMessage()</i> method.
     *
     * @return <status code> <status description> - <message description>
     */
    public String getMessage() {
        return statusCode
             + " "
             + getSyncMLMessage()
             + " - "
             + super.getMessage()
             ;
    }
}
