/*

 Copyright (c) 2003-2004 sync4j project
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.

 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.

 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

*/
package sync4j.framework.server.session;

import java.util.ArrayList;

import sync4j.framework.core.AbstractCommand;
import sync4j.framework.core.AlertCommand;
import sync4j.framework.core.MapCommand;
import sync4j.framework.core.SyncCommand;

/** 
 * This class represents the state of the Syncronization process because cache 
 * all informations that could be used in that process.
 * It is set during the Initialization process.
 *
 * @author Luigia Fassina @ funambol.com
 * @version $Id: SyncState.java,v 1.2 2003/11/02 15:11:32 stefano_fornari Exp $
 */
public class SyncState {
    
    // ---------------------------------------------------------- Public Methods
    
    /**
     * Cache all AbstractCommand (Alert, Put, Get)
     */
    private AbstractCommand[] clientCommands = null;
    private ArrayList listClientCommands = new ArrayList();
   
    public void addClientCommands(AbstractCommand[] abstractCmd) {
        for (int i=0; ((clientCommands != null) && (i<clientCommands.length)); i++) {
            listClientCommands.add(clientCommands[i]);
        }
        
        this.clientCommands = (AbstractCommand[])listClientCommands.toArray(new AbstractCommand[listClientCommands.size()]);
    }
    
    public AbstractCommand[] getClientCommands() {
        return this.clientCommands;
    }

    /**
     * Cache the AlertCommand
     */
    private AlertCommand[] clientAlerts = null;
    private ArrayList listClientAlerts = new ArrayList();
   
    public void addClientAlerts(AlertCommand[] clientAlerts) {
        for (int i=0; ((clientAlerts != null) && (i<clientAlerts.length)); i++) {
            listClientAlerts.add(clientAlerts[i]);
        }
        
        this.clientAlerts = (AlertCommand[])listClientAlerts.toArray(new AlertCommand[listClientAlerts.size()]);
    }
    
    public void resetClientAlerts() {
        clientAlerts = new AlertCommand[0];
        listClientAlerts = new ArrayList();
    }
    
    public AlertCommand[] getClientAlerts() {
        return this.clientAlerts;
    }
    
    /**
     * Cache the MapCommand
     */
    private MapCommand[] mapCommands = null;
    private ArrayList listMapCommands = new ArrayList();
    
    public void addMapCommands(MapCommand[] mapCommands) {
        for (int i=0; ((mapCommands != null) && (i<mapCommands.length)); i++) {
            listMapCommands.add(mapCommands[i]);
        }
        
        this.mapCommands = (MapCommand[])listMapCommands.toArray(new MapCommand[listMapCommands.size()]);
    }
    
    public MapCommand[] getMapCommands() {
        return this.mapCommands;
    }
    
    /**
     * Cache the SyncCommand
     */
    private SyncCommand[] syncCommands = null;
    private ArrayList listSyncCommands = new ArrayList();
    
    public void addSyncCommands(SyncCommand[] syncCommands) {
        for (int i=0; ((syncCommands != null) && (i<syncCommands.length)); i++) {
            listSyncCommands.add(syncCommands[i]);
        }
        
        this.syncCommands = (SyncCommand[])listSyncCommands.toArray(new SyncCommand[listSyncCommands.size()]);
    }
    
    public SyncCommand[] getSyncCommands() {
        return this.syncCommands;
    }
    
}
