/*

 $Id: ArrayUtils.java,v 1.2 2003/12/15 16:58:28 luigiafassina Exp $

 Copyright (c) 2001 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.  
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */

package sync4j.framework.tools;

import java.lang.reflect.Array;


/**
 * Collection of tools for the server
 *
 * @author  Stefano Fornari
 */
public class ArrayUtils {
    
    /**
     * Merges the two given arrays in a single array, putting the elements of 
     * the former array first and the elements of the latter array. The returned 
     * array will be of the type specified by <i>elementClass</i>
     *
     * @param a the former array - NULL
     * @param b the latter array - NULL
     * @param elementType the class of the elements
     *
     * @return an array containing the elements of <i>a</i> and <i>b</i>
     */
    public static Object mergeArrays(Object[] a, Object[] b, Class elementType) {
        
        int size = 0;
        
        if (a != null) size += a.length;
        if (b != null) size += b.length;

        Object newArray = Array.newInstance(elementType, size);
        
        int newArrayPos = 0;
        if (a != null) {
            System.arraycopy(a, 0, newArray, newArrayPos, a.length);
            newArrayPos = a.length;
        }
         
        if (b != null) {
            System.arraycopy(b, 0, newArray, newArrayPos, b.length);
        }
        
        return newArray;

    }
    
}
