/*

 $Id: Sync4jEngineFactory.java,v 1.8 2003/12/15 17:06:05 luigiafassina Exp $

 Copyright (c) 2001 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.  
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */
package sync4j.server.engine;

import java.io.*;

import sync4j.framework.core.Sync4jException;
import sync4j.framework.engine.SyncEngine;
import sync4j.framework.engine.SyncEngineFactory;
import sync4j.framework.config.Configuration;

/**
 * This is the factory of the <i>SyncEngine</i> object that will be used by the
 * Sync4j server.
 * <p>
 * For now the class of the SyncEngine is hardcoded in the factory and a 
 * <i>Sync4jEngine</i> is created. Future enhanchements will make this class 
 * more flexible and useful.
 * 
 * @author  Stefano Fornari @ Funambol
 */
public class Sync4jEngineFactory  
implements SyncEngineFactory, Serializable {
    // ------------------------------------------------------------ Private data
    
    private Configuration configuration;
    
    // -------------------------------------------------------------- Properties
    
    private String syncStrategyName = null;
    
    public String getSyncStrategyName() {
        return syncStrategyName;
    }
    
    public void setSyncStrategyName(String syncStrategyName) {
        this.syncStrategyName = syncStrategyName;
    }
    // ---------------------------------------------------------- Public methods
    
    /**
     * Returns the <i>SyncEngine</i> object to be used, creating it if necessary.
     *
     * @return the <i>SyncEngine</i> used by the Syn4j server
     *
     * @throws Sync4jException
     */
    public synchronized SyncEngine getSyncEngine() throws Sync4jException {
        return new Sync4jEngine(configuration);
    }
    
    /** 
     * Configure the factory with a <i>Configuration</i> object. This can
     * eventually be passed to the created sync engine.
     *
     * @param configuration the configuration object
     *
     */
    public void setConfiguration(Configuration configuration) {
        this.configuration = configuration;
    }

    // -------------------------------------------------------------------- main
}
