/*
 Copyright (c) 2001 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.  
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */
package sync4j.server.engine;

import sync4j.framework.core.ModificationCommand;
import sync4j.framework.engine.SyncOperationStatusImpl;
import sync4j.framework.engine.SyncOperation;
import sync4j.framework.engine.source.SyncSource;

/**
 * This class represents a SyncOperation excecuted by Sync4j. The main 
 * difference between this and a normal <i>SyncOperationStatusImpl</i> is that
 * a <i>Sync4jOperationStatus</i> is associated to a SyncML command (such as
 * &lt;Add&gt;, &lt;Delete&gt;, ecc).
 *
 * @author  Stefano Fornari @ Funambol
 * @version $Id: Sync4jOperationStatus.java,v 1.2 2003/04/19 10:33:04 stefano_fornari Exp $
 */
public abstract class Sync4jOperationStatus extends SyncOperationStatusImpl {
    
    // -------------------------------------------------------------- Properties
    
    /**
     * The command this status related to
     */
    protected ModificationCommand cmd = null;
    
    /** Getter for property cmd.
     * @return Value of property cmd.
     *
     */
    public ModificationCommand getCmd() {
        return cmd;
    }
    
    /**
     * Setter for property  cmd.
     *
     * @param cmd the cmd
     */
    public void setCommand(ModificationCommand cmd) {
        this.cmd = cmd;
    }
    
    /** Creates a new instance of Sync4jOperationStatus */
    public Sync4jOperationStatus(SyncOperation       operation , 
                                 SyncSource          syncSource,
                                 ModificationCommand cmd       ) {
        super(operation, syncSource);
        this.cmd = cmd;
    }
    
    /** Creates a new instance of Sync4jOperationStatus */
    public Sync4jOperationStatus(SyncOperation operation , 
                                 SyncSource    syncSource) {
        this(operation, syncSource, null);
    }
}
