/*
 Copyright (c) 2001-2002-2003 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.
 
 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:
 
     "This product includes software developed by the
      sync4j project."
 
 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE. 
*/

package sync4j.server.engine;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * This class represent an addressable SyncML source registered to Sync4j.
 * It is not intended to store specific SyncSource information.
 *
 * @author  Stefano Fornari @ Funambol
 * 
 * @version $Id: Sync4jSource.java,v 1.5 2003/12/12 17:47:48 luigiafassina Exp $
 */
public class Sync4jSource {
    
    private String uri;   // the source uri
    private String config; // the source configuration file
    private String sourceTypeId; // the source type id
    private String sourceName; //the source name
    
    /** Creates a new instance of Sync4jSyncSource */
    public Sync4jSource() {
        this(null, null, null, null);
    }
    
    public Sync4jSource(String uri, String config) {
        this.uri    = uri   ;
        this.config = config;
    }

    public Sync4jSource(String uri, String config, String sourceTypeId, String sourceName) {
        this.uri    = uri   ;
        this.config = config;
        this.sourceTypeId = sourceTypeId;
        this.sourceName = sourceName;
    }
    
    /** Getter for property name.
     * @return Value of property name.
     *
     */
    public String getUri() {
        return uri;
    }    
    
    /** Setter for property name.
     * @param name New value of property name.
     *
     */
    public void setName(String uri) {
        this.uri = uri;
    }
    
    /** Getter for property config.
     * @return Value of property config.
     *
     */
    public String getConfig() {
        return config;
    }
    
    /** Setter for property config.
     * @param config New value of property config.
     *
     */
    public void setConfig(String config) {
        this.config = config;
    }
    
    /** Getter for property sourceTypeId.
     * @return Value of property sourceTypeId.
     *
     */
    public String getSourceTypeId() {
        return sourceTypeId;
    }
    
    /** Setter for property sourceTypeId.
     * @param config New value of property sourceTypeId.
     *
     */
    public void setSourceTypeId(String sourceTypeId) {
        this.sourceTypeId = sourceTypeId;
    }
    
    /** Getter for property sourceName.
     * @return Value of property sourceName.
     *
     */
    public String getSourceName() {
        return sourceName;
    }
    
    /** Setter for property sourceName.
     * @param config New value of property sourceName.
     *
     */
    public void setSourceName(String sourceName) {
        this.sourceName = sourceName;
    }
        
    public String toString() {
        ToStringBuilder sb = new ToStringBuilder(this);

         sb.append("uri",     uri  );
         sb.append("config", config);
         sb.append("sourceTypeId", sourceTypeId);
         sb.append("sourceName", sourceName);

         return sb.toString();
    }
    
}
