/*
 Copyright (c) 2001 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.  
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.
*/

package sync4j.server.engine;

import sync4j.framework.engine.SyncItem;
import sync4j.framework.engine.SyncItemKey;
import sync4j.framework.engine.SyncItemImpl;

import sync4j.framework.core.Item;
import sync4j.framework.core.Data;
import sync4j.framework.core.Target;
import sync4j.framework.core.Source;

/**
 * Helper class to convert <i>SyncItem</i>s into <i>Item</i>s and vice versa.
 *
 * @author Stefano Fornari @ Funambol
 *
 * @version  $Id: SyncItemHelper.java,v 1.4 2003/12/15 17:06:05 luigiafassina Exp $
 * 
 */
public class SyncItemHelper {
    // ---------------------------------------------------------------- Costants
    
    public static final String PROPERTY_COMMAND = "SYNC4J_COMMAND";

    // ---------------------------------------------------------- Public methods
    
    /**
     * Converts a generic <i>SyncItem</i> into an <i>Item</i> object.
     *
     * @param key the key the item is known by the client agent
     * @param syncItam the <i>SyncItem</i>
     * @param includeTarget <i>true</i> if the target must be included
     * @param includeSource <i>true</i> if the source must be included
     * @param includeData <i>true</i> if data must be included
     *
     * @return the <i>Item</i> object
     */
    public static Item toItem(String   key          ,
                              SyncItem syncItem     ,
                              boolean  includeTarget,
                              boolean  includeSource,
                              boolean  includeData  ) {
        Data data = null;

        if (includeData) {
            data = new Data(
                       new String((byte[])syncItem.getPropertyValue(SyncItem.PROPERTY_BINARY_CONTENT))
                   );
        }
        
        Target target = null;
        Source source = null;
        
        if (includeTarget) {
            target = new Target(key);
        }
        
        if (includeSource) {
            source = new Source(key);
        }

        return new Item(target,
                        source,
                        null  , // meta
                        data  );
    }
    
    /**
     * Create a new <i>SyncItem</i> with the content of an existing one. The 
     * old SyncItem's key becomes the mappedKey of the new SyncItem.
     *
     * @param key
     * @param fromSyncItem
     */
    public static SyncItem newMappedSyncItem(SyncItemKey key, SyncItem fromSyncItem) {
        SyncItemImpl syncItem 
            = new SyncItemImpl(fromSyncItem.getSyncSource()          ,
                               key.getKeyAsString()                  ,
                               fromSyncItem.getKey().getKeyAsString(),
                               fromSyncItem.getState()               );
        
        syncItem.setProperties(fromSyncItem.getProperties());
        
        return syncItem;       
    }
}
