/*
 Copyright (c) 2001-2003 sync4j project
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.

 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.

 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.
*/


package sync4j.test.tools;

import sync4j.framework.tools.IOTools;

import java.io.*;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import sync4j.framework.core.Sync4jException;
import sync4j.framework.tools.WBXMLTools;

/**
 * <p>Title: </p>
 * <p>Description: A utility to convert XML files to WBXML and vice versa.</p>
 * <p>Copyright: Copyright (c) 2003</p>
 * <p>Company: </p>
 *
 * @author Tyson Norris
 *
 * @version $Id: WBXMLConverter.java,v 1.3 2003/12/15 17:08:08 luigiafassina Exp $
 */

public class WBXMLConverter {
    private static boolean xmlToWbxml = false;
    private static boolean wbxmlToXml = false;
    
    public WBXMLConverter() {
    }

    public static void main(String args[])
    throws Exception {
        try {
            checkArguments(args);
        } catch (IllegalArgumentException e) {
            System.out.println("usage:" );
            System.out.println(WBXMLConverter.class.getName() + " [-xml|-wbxml] <xml dir>");
            return;
        }
        
        convert((args.length == 1) ? args[0] : args[1]);
    }
    
    private static void checkArguments(String[] args) 
    throws IllegalArgumentException {
        switch (args.length) {
            case 0:
                throw new IllegalArgumentException();
            
            case 1:
                wbxmlToXml = false;
                xmlToWbxml = true ;
                break;
            
            case 2:
                wbxmlToXml = "-wbxml".equalsIgnoreCase(args[0]);
                xmlToWbxml = "-xml".equalsIgnoreCase(args[0]);
                
                if (!wbxmlToXml && !xmlToWbxml) {
                    throw new IllegalArgumentException();
                }
                break;
            
            default:
                throw new IllegalArgumentException();
        }
    }
    
    private static void convert(String xmlPath) 
    throws IOException, Sync4jException {
        System.out.println("converting xmlPath:" + xmlPath);
        
        File xmlDir = new File(xmlPath);
        List filesToConvert = getFilesInDir(xmlDir);
        for (Iterator it=filesToConvert.iterator();it.hasNext();){
            try {
                File file = (File)it.next();
                System.out.println("file:" + file.getAbsolutePath());
                
                if (xmlToWbxml) {
                    xmlToWbxml(file);
                }
                if (wbxmlToXml) {
                    wbxmlToXml(file);
                }

            } catch (Exception ex){
                ex.printStackTrace();
            }
        }
    }
    
    private static void xmlToWbxml(File file) 
    throws IOException, Sync4jException {
        String xml = IOTools.readFileString(file);
        
        byte[] wbxml = WBXMLTools.toWBXML(xml);

        String xmlFileName = file.getAbsolutePath();
        String wbxmlFileName = xmlFileName.substring(0, xmlFileName.lastIndexOf("."));
        wbxmlFileName = wbxmlFileName + ".wbxml";
        
        //now write the wbxml to a file
        System.out.println("Writing to: " + wbxmlFileName);
        IOTools.writeFile(wbxml, wbxmlFileName);
    }
    
    private static void wbxmlToXml(File file) 
    throws IOException, Sync4jException {
        byte[] wbxml = IOTools.readFileBytes(file);
        
        String xml = WBXMLTools.wbxmlToXml(wbxml);

        String wbxmlFileName = file.getAbsolutePath();
        String xmlFileName = wbxmlFileName.substring(0, wbxmlFileName.lastIndexOf("."));
        xmlFileName = xmlFileName + ".xml";
        
        //now write the xml to a file
        System.out.println("Writing to: " + xmlFileName);
        IOTools.writeFile(xml, xmlFileName);
    }

    private static List getFilesInDir(File dir){
        List files = new ArrayList();
        File[] dirFiles = dir.listFiles();
        for (int i=0; ((dirFiles != null) && (i<dirFiles.length)); i++){
            File file = dirFiles[i];
            if (file.isFile()){
                if (xmlToWbxml) {
                    if (file.getName().toUpperCase().endsWith(".XML")){
                        files.add(file);
                    }
                } else {
                    if (file.getName().toUpperCase().endsWith(".WBXML")){
                        files.add(file);
                    }
                }
            } else {
                files.addAll(getFilesInDir(file));
            }
        }
        return files;
    }

    
    public static String readWbxmlAsXml(File wbxmlFile) 
    throws IOException, Sync4jException {
        FileInputStream fis = new FileInputStream(wbxmlFile);
        byte[] byteArray = new byte[(int)wbxmlFile.length()];
        int count = fis.read(byteArray);
        fis.close();

        return WBXMLTools.wbxmlToXml(byteArray);
    }
}