/*
 Copyright (c) 2001 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.  
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */

package sync4j.transport.http.server;

import java.util.HashMap;

import javax.servlet.http.*;
import javax.naming.*;
import javax.ejb.CreateException;
import javax.ejb.RemoveException;
import javax.ejb.EJBException;

import sync4j.framework.transport.http.SyncHolder;
import sync4j.framework.server.SyncResponse;
import sync4j.server.syncbean.SyncLocal;
import sync4j.server.syncbean.SyncHomeLocal;

import sync4j.framework.core.Sync4jException;
import sync4j.framework.server.error.ServerException;
import sync4j.framework.server.error.ServerFailureException;
import sync4j.framework.server.error.NotImplementedException;
import sync4j.framework.protocol.ProtocolException;

/**
 * Implementes a <i>SyncHolder</i> wrapping a local EJB.
 *
 * @author  Stefano Fornari @ Funambol
 * @version $Id: LocalEJBSyncHolder.java,v 1.5 2003/01/08 18:07:05 stefano_fornari Exp $
 */
public class LocalEJBSyncHolder implements SyncHolder {
    
    // --------------------------------------------------------------- Constants
    
    public static final String SYNCEJB_HOME_JNDI_NAME = "java:comp/env/ejb/SyncBean";
    
    // ------------------------------------------------------------ Private data

    private SyncLocal     sync      = null;
    private String        sessionId = null;
    private SyncHomeLocal home      = null;

    // ------------------------------------------------------------ Constructors
    
    public LocalEJBSyncHolder() throws NamingException {
        InitialContext ctx = new InitialContext();
        home = (SyncHomeLocal)ctx.lookup(SYNCEJB_HOME_JNDI_NAME);
    }
    
    // ---------------------------------------------------------- Public methods
    
    /** Processes an incoming message.
     *
     * @param requestData the SyncML request as stream of bytes
     * @param contentType the content type associated with the request
     *
     * @return the SyncML response as a <i>ISyncResponse</i> object
     *
     * @throws ServerException in case of a server error
     *
     */
    public SyncResponse processMessage(byte[] requestData, String contentType) 
    throws ServerException {
        return sync.processMessage(requestData, contentType);
    }    
    
    public void setSessionId(String sessionId) throws Sync4jException {
        try {
            sync = home.create(sessionId);
        } catch (CreateException e) {
            throw new ServerFailureException(e);
        }
            
        this.sessionId = sessionId;
    }
    
    public String getSessionId() {
        return sessionId;
    }
    
    /** Called when the SyncHolder is not required any more. It gives the holder
     * an opportunity to do clean up and releaseing of resources.
     *
     * @throws java.lang.Exception in case of error. The real exception is stored
     * in the cause.
     *
     */
    public void close() throws Exception {
        try {
            sync.remove();
        } catch (RemoveException e) {
            throw new Exception("Error in closing the SyncHolder", e);
        } catch (EJBException e) {
            throw new Exception("Error in closing the SyncHolder", e);
        }
    }    
    
    
}
