/* 
Copyright (c) 2001-2002 sync4j project
All rights reserved.
 
Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:
 
1. Redistributions of source code must retain the above copyright
notice, this list of conditions, and the following disclaimer.
 
2. Redistributions in binary form must reproduce the above copyright
notice, this list of conditions, and the disclaimer that follows
these conditions in the documentation and/or other materials
provided with the distribution.
 
3. The name "sync4j" must not be used to endorse or promote products
derived from this software without prior written permission.
 
4. Products derived from this software may not be called "sync4j", nor
may "sync4j" appear in their name, without prior written permission.
 
In addition, we request (but do not require) that you include in the
end-user documentation provided with the redistribution and/or in the
software itself an acknowledgement equivalent to the following:
 
"This product includes software developed by the
sync4j project."
 
THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
SUCH DAMAGE. 
 */

package sync4j.transport.j2me.http.client;

import sync4j.framework.IConnectionFactory;
import sync4j.framework.IConnection;
import sync4j.protocol.SyncClientAgent;

import sync4j.framework.core.Message;

import javax.microedition.io.StreamConnection;
import javax.microedition.io.HttpConnection;
import javax.microedition.io.Connector;
import javax.microedition.lcdui.StringItem;
import javax.microedition.lcdui.Form;
import java.lang.InterruptedException;
import java.io.IOException;
import java.io.InputStream;

/**
 * This class is the http client handling the exchanges between a j2me client
 * and a SyncML server, as located by an URL.  The implementation synchronized
 * the <code>run</code> method and introduced the <code>wait</code> method
 * so as to enforce communicating one thread at a time upon user pressing
 * "connect" button excessively.  
 * Also, we keep a single thread for communication all the time, instead of 
 * pressing Connect button each time.  As a result, it saves the j2me device
 * from sparing precious resource on creating a thread everytime.  Courtesy of 
 * <a href="http://wireless.java.sun.com/midp/articles/threading/">this article</a>
 * 
 * @author  <a href="mailto:sso@users.sourceforge.net">Simon So</a>
 * @since SyncML 1.1 
 * @version $Id: SyncMLClient.java,v 1.2 2003/01/15 15:41:16 stefano_fornari Exp $
 */
public class SyncMLClient implements Runnable {
    private IConnection cc; 
    private boolean isTrucking;         // is transferring
    private boolean isCancel;
    private Form outputForm;
    private String url;
    private int command;
    
    /**
     * Constructs a sync ml client.
     * 
     * @param url   the URL of the sync server
     * @param outputForm    the output UI
     */
    public SyncMLClient(String url, Form outputForm) {
        this.outputForm = outputForm;
        this.isTrucking = true;
        this.url = url;
        this.cc = null;
        this.command = 0;         // base Alert Code
    }

    /**
     * Waits for the connection to take place.  If a command comes in, 
     * connect.
     */
    public synchronized void run() {
        while (isTrucking) {
            try {
                wait();
            } catch (InterruptedException ie) {
            }
            if (isTrucking) {
                connect();
            }
        }
    }
        
    /**
     * Sets up the client-to-server exchange.  The sync type is determined by 
     * the member <code>command</code>.  This http connection is not
     * persistent, because there is some problems in j2mewtk.  Will rectify.
     *
     * @see <a href="http://www.syncml.org/docs/syncml_http_v11_20020215.pdf">section 5.3</a>
     */
    private void connect() {
        try {            
            // improper way of generating a message; should have constructed
            // in SyncClientAgent!!!!!!
            StringBuffer buff = new StringBuffer();
            StreamConnection ic = (StreamConnection)Connector.open(
                    "http://localhost:8000/AddCommand-basic.xml", 
                    Connector.READ);
            InputStream in = ic.openInputStream();
            int ch;
            ic.close(); // doesn't close input stream!
            while( ( ch = in.read() ) != -1 ){
                buff.append((char) ch );
            }
            in.close();
            // improper...
            
            SyncClientAgent sca = new SyncClientAgent(command);
            while (!sca.isFinal()) {
                cc = new ClientConnectionFactoryImpl().getConnection(url);                
                cc.prepareConnection();
                cc.send(sca.prepareMessage(new Message(buff.toString())));
                Message received = cc.receive();          
                sca.processMessage(received);
                
                //  feedback status code here
                StringItem i = new StringItem("From server ", received.toString().substring(0, 10));
                outputForm.append(i);
                
                cc.closeConnection();                
            }
        } catch (IOException ioe) {
            ioe.printStackTrace();
            if (!isCancel) {
                try {
                    cc.closeConnection();
                } catch (IOException e) {
                }
            }
            isCancel = false;
        } finally {
        }
    }

    /**
     * Sets the synchronization type and notifies the thread to establish
     * the connection.
     *
     * @param cmd   the synchronization type
     */
    public synchronized void executeCommand(int cmd) {
        command = cmd;
        notify();
    }
    
    public void cancel() {
        try {
            isCancel = true;
            cc.closeConnection();
        } catch (IOException ioe) {
        }
    }
    
    public synchronized void stop() {
        isTrucking = false;
        notify();
    }
}
