/*
 
 $Id: MD5AuthenticationTest.java,v 1.2 2002/08/09 15:16:33 stefano_fornari Exp $
 
 Copyright (c) 2001-2002 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.
 
 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:
 
     "This product includes software developed by the
      sync4j project."
 
 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.
 
 */

package sync4j.framework.core;

import junit.framework.*;

import sync4j.framework.core.MD5Authentication;
import sync4j.framework.core.NextNonce;


/**
 * Tests the <code>MD5Authentication</code>.
 *
 * @author	<a href="mailto:sso@users.sourceforge.net">Simon So</a>
 * @see		sync4j.framework.core.MD5Authentication
 * @since	SyncML 1.1
 */
public class MD5AuthenticationTest extends TestCase
{
    NextNonce nextNonce;
    
    /**
     * Defines the testcase name for JUnit.
     *
     * @param theName the testcase's name.
     */
    public MD5AuthenticationTest(String theName)
    {
        super(theName);
        nextNonce = null;
    }
    
    /**
     * @return a test suite (<code>TestSuite</code>) that includes all methods
     *         starting with "test"
     */
    public static Test suite()
    {
        return new TestSuite(MD5AuthenticationTest.class);
    }
    
    protected void setUp() {
        // some arbitary string...
        nextNonce = new NextNonce("j2me", true);
    }
    
    /**
     *	Tests 
     */
    public void testConstructor() {
        MD5Authentication goodMD5 = new MD5Authentication(
                                        "sync4j",
                                        "forSyncML",
                                        nextNonce);
        String data = goodMD5.getData();
        assertTrue(goodMD5 != null);
        assertTrue(data != null);
        assertTrue(data.equals("htJOdrmNAxW3FityzgsUxQ=="));
        assertTrue(nextNonce == goodMD5.getNextNonce());
    }
    
    public void testBadUserName() {
        MD5Authentication badUserName = null;
        try {
            badUserName = new MD5Authentication(
                                        null,
                                        "forSyncML",
                                        nextNonce);
        } catch (Exception e) {
            assertTrue(e instanceof NullPointerException);
            assertTrue(badUserName == null);
        }
    }
    
    public void testBadPassword() {
        MD5Authentication badPassword = null;
        try {
            badPassword = new MD5Authentication(
                                        "sync4j",
                                        null,
                                        nextNonce);
        } catch (Exception e) {
            assertTrue(e instanceof NullPointerException);
            assertTrue(badPassword == null);
        }
    }
}
