/*

 $Id: SyncCapabilitiesTest.java,v 1.4 2002/08/09 15:16:33 stefano_fornari Exp $

 Copyright (c) 2001, 2002 sync4j project
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:
 
 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.
 
 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows 
    these conditions in the documentation and/or other materials 
    provided with the distribution.

 3. The name "sync4j" must not be used to endorse or promote products
    derived from this software without prior written permission.  
 
 4. Products derived from this software may not be called "sync4j", nor
    may "sync4j" appear in their name, without prior written permission.
 
 In addition, we request (but do not require) that you include in the 
 end-user documentation provided with the redistribution and/or in the 
 software itself an acknowledgement equivalent to the following:

     "This product includes software developed by the
      sync4j project."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE SYNC4J AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.

 */


package sync4j.framework.core;

import sync4j.framework.core.*;
import junit.framework.*;
import java.io.*;

/**
  *
  *  unit test code for the SyncCapabilities class
  *
  *  @see sync4j.framework.core.SyncCapabilities
  *  @author Sean C. Sullivan
  *
  */
public class SyncCapabilitiesTest 
	extends junit.framework.TestCase
{

	public SyncCapabilitiesTest(final String strName)
	{
		super(strName);
	}

        public void testConstructor_exceptions()
        {
		boolean bCaughtException = false;

		SyncCapabilities cap = null;

		try
		{
			SyncType[] nullParam = null;
		   cap = new SyncCapabilities(nullParam);
		   assertTrue(false);
		}
		catch (NullPointerException ex)
		{
		   bCaughtException = true;
		}
		assertTrue(bCaughtException);

		try
		{
		   SyncType[] types = new SyncType[3];
		   types[0] = SyncType.TWO_WAY;
		   types[1] = null;
		   types[2] = SyncType.SERVER_ALERTED;
		   cap = new SyncCapabilities(types);
		   assertTrue(false);
		}
		catch (NullPointerException ex)
		{
		   bCaughtException = true;
		}
		assertTrue(bCaughtException);

		bCaughtException = false;
		try
		{
		   cap = new SyncCapabilities(new SyncType[0]);
		   assertTrue(false);
		}
		catch (IllegalArgumentException ex)
		{
		   bCaughtException = true;
		}
		assertTrue(bCaughtException);

        }

	public void testConstructor()
	{

		SyncType[] types = new SyncType[7];
		types[0] = SyncType.TWO_WAY;
		types[1] = SyncType.SLOW;
		types[2] = SyncType.ONE_WAY_FROM_CLIENT;
		types[3] = SyncType.REFRESH_FROM_CLIENT;
		types[4] = SyncType.ONE_WAY_FROM_SERVER;
		types[5] = SyncType.REFRESH_FROM_SERVER;
		types[6] = SyncType.SERVER_ALERTED;

		SyncCapabilities cap = null;
		
		boolean bCaughtException = false;

		try
		{
			cap = new SyncCapabilities(types);
		}
		catch (Exception ex)
		{
			bCaughtException = true;
		}
	
		assertTrue( bCaughtException == false );

		assertTrue( cap != null );

		SyncType[] types2 = cap.getSyncTypes();

		assertTrue( types2 != null );

		assertTrue( types.length == types2.length );

		assertTrue( java.util.Arrays.equals(types, types2) );
	}

}
